@@ -43,6 +43,8 @@ DEFAULT_GLOBAL_CONFIG = {
     'rgbaColormap' : False,
     'disableTrayIcon' : False,
     'overrideDesktop' : '',
+    'overrideMail' : '',
+    'startup' : 'default',
     'dontShowAvatarInLoginWindow' : 0,
 }
 
@@ -73,7 +75,7 @@ DEFAULT_USER_CONFIG = {
     'convInputHeight' : 140,
     'convListWidth' : 130,
     'saveLogsAutomatically' : False,
-    'activePlugins': 'PersonalMessageV2,Plus', # CSV of plugin names
+    'activePlugins': 'Plus', # CSV of plugin names
     'emoticonDir': '',
     'avatarDir' : '',
     'avatarPath' : '',
@@ -94,6 +96,7 @@ DEFAULT_USER_CONFIG = {
     'showUserPanel' : True,
     'showSearchEntry' : True,
     'showStatusCombo' : True,
+    'statusComboOnTop' : False,
     'showMenubar' : True,
     'showMenu' : True,
     'showHeader' : True,
@@ -135,6 +138,29 @@ DEFAULT_USER_CONFIG = {
     'avatarsOnRight' : True,
     'receiveP4context' : False,
     'preventClosingTime' : False,
+    'showLastMessageReceivedAt' : True,
+    'enableSounds' : True,
+    'soundsplayOnline' : True,
+    'soundsplayOffline' : True,
+    'soundsmuteSound' : False,
+    'soundsplayMessage' : True,
+    'soundsplayNudge' : True,
+    'soundsplayTransfer' : True,
+    'soundsplayInactive' : True,
+    'soundsplaySend' : False,
+    'soundsplayError' : False,
+    'soundsdisableBusy' : False,
+    'soundstheme' : 'default',
+    'soundsbeep' : False,
+    'toolFontType' : True,
+    'toolFontColor' : True,
+    'toolFontStyle' : True,
+    'toolSmilies' : True,
+    'toolNudge' : True,
+    'toolInvite' : True,
+    'toolSendFile' : True,
+    'toolWebcam' : True,
+    'toolClear' : True,    
 }
 
 class Config(gobject.GObject):
