@@ -18,6 +18,10 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import os
+# needed for osx #
+import pygtk
+pygtk.require('2.0')
+##################
 import gtk
 import sys
 import time
@@ -44,6 +48,7 @@ import TrayIcon
 import MainWindow
 import StatusMenu
 import SlashCommands
+import Sound
 import PluginManager
 import PluginManagerDialog
 import ConversationManager
@@ -90,17 +95,17 @@ class Controller(gobject.GObject):
         (gobject.TYPE_PYOBJECT,)),
     }
 
-    def __init__(self, username, minimized, safe, leakdebug, iconified):
+    def __init__(self, username, minimized, leakdebug, iconified, badroot):
         '''Constructor'''
         gobject.GObject.__init__(self)
 
         self.NAME = 'emesene'
-        self.VERSION = '1.5 - awesome'
+        self.VERSION = '1.6 "mate"'
         self.COPYRIGHT = 'Luis Mariano Guerra, dx, C10uD'
         self.COMMENT = _('A client for the WLM%s network') % u'\u2122'
         self.LICENSE_FALLBACK = 'GNU General Public License'
         self.WEBSITE = 'http://www.emesene.org'
-        self.BUGTRACKER = 'http://redmine.emesene.org/projects/emesene1/issues'
+        self.BUGTRACKER = 'http://forum.emesene.org/index.php/board,19.0.html'
         self.AUTHORS = [
             'Luis Mariano \'wariano\' Guerra (emesene and emesenelib)', \
             'dequis \'dx\' (emesene and emesenelib)', \
@@ -131,21 +136,28 @@ class Controller(gobject.GObject):
             'Pablo \'pablo\' Mazzini (emesene and emesenelib)', \
             'scyx (emesene)', \
             'arielj (emesene)', \
+            'Victor C. (gnome-colors theme)', \
+            'GrinningArmor (emesene)', \
+            'x-warrior (emesene)', \
+            'Tom \'ukblackknight\' (emesene)', \
             'All the fantastic emesene community (all)', \
             ]
         
+        # this statuses are not available in wlm anymore
+        self.bad_statuses = [ 'BRB', 'PHN', 'LUN', 'FLN' ]
+
         self.status_ordered = [
             [ 'NLN', 'AWY', 'BSY', 'BRB', 'PHN', 'LUN', 'HDN', 'IDL', 'FLN' ],
 
-            [ 'online', 'away', 'busy', 'brb', 'phone',
-             'lunch', 'invisible', 'idle', 'offline' ],
+            [ 'online', 'away', 'busy', 'away', 'busy',
+             'away', 'invisible', 'idle', 'offline' ],
 
-            [ _('Online'), _('Away'), _('Busy'), _('Be right back'),
-             _('On the phone'), _('Gone to lunch'), _('Invisible'),
+            [ _('Online'), _('Away'), _('Busy'), _('Away'),
+             _('Busy'), _('Away'), _('Invisible'),
              _('Idle'), _('Offline') ],
 
-            [ _('_Online'), _('_Away'), _('_Busy'), _('Be _right back'),
-             _('On the _phone'), _('Gone to _lunch'), _('_Invisible'),
+            [ _('_Online'), _('_Away'), _('_Busy'), _('_Away'),
+             _('_Busy'), _('_Away'), _('_Invisible'),
              _('I_dle'), _('O_ffline') ]
         ]
 
@@ -179,6 +191,7 @@ class Controller(gobject.GObject):
         # are ready in                            #
         # mainwindow.userlist.tooltips            #
         self.tooltipColor = None
+        self.niceBarWarningColor=gtk.gdk.Color(57600,23040,19712)
         # ####################################### #
         self.widget_style = self.mainWindow.get_style()
         self.unifiedParser = UnifiedParser(self.theme)
@@ -199,12 +212,12 @@ class Controller(gobject.GObject):
         if use_rgba_colormap:
             gtk.widget_pop_colormap()
 
-        if TrayIcon.disabled or not minimized:
-            if iconified:
+        if TrayIcon.disabled or not (minimized or self.config.glob['startup'] == 'minimize'):
+            if iconified or self.config.glob['startup'] == 'iconify':
                 self.mainWindow.iconify()
             else:
                 self.mainWindow.show()
-        if minimized:
+        if minimized or self.config.glob['startup'] == 'minimize':
             self.mainWindow.show()
             self.mainWindow.iconify()
 
@@ -215,7 +228,6 @@ class Controller(gobject.GObject):
             self.theme.getImage('icon16'), self.theme.getImage('icon32'),
             self.theme.getImage('icon48'), self.theme.getImage('icon96'))
 
-        self.autoReplyMessage = ''
         self.msn = None
         self.lastILN = 0
         self.pendingAvatars = {}
@@ -230,7 +242,6 @@ class Controller(gobject.GObject):
         self.preference_open = False
         self.addBuddy = None
 
-        self.safemode = safe
         self.leakdebug = leakdebug
 
         if username in self.mainWindow.login.users.getUsers():
@@ -261,7 +272,7 @@ class Controller(gobject.GObject):
 
         if not self.config.glob['debug']:
             print "If you are reading this, you may want to enable debug"
-            print "It's the first option in the connection tab in preferences"
+            print "It's the first option in the advanced page in preferences"
 
         server = SERVER_HOST
         proxy = None
@@ -278,7 +289,7 @@ class Controller(gobject.GObject):
 
         # messenger.hotmail.com
         self.msn = core.Msnp(server, 1863, user, password,\
-             self.config.getUserConfigPath(), proxy, self.safemode, \
+             self.config.getUserConfigPath(), proxy, \
              self.config.user['receiveP4context']) # ugly, but i'm lazy
                     
         self.msn.setDebug(self.config.glob['debug'],
@@ -288,6 +299,11 @@ class Controller(gobject.GObject):
         self.msn.connect('login-successful', self.on_login_successful)
         gobject.timeout_add(2000, self.trayicon_effect)
 
+        self.contacts = ContactManager.ContactManager(
+                                dialog, self.msn, self.userEmail)
+        self.groups = GroupManager.GroupManager(
+                                dialog, self.msn)
+
         self.msn.login()
 
     def trayicon_effect(self):
@@ -307,8 +323,8 @@ class Controller(gobject.GObject):
         if not self.reconnecting:
             text = _('Error during login, please retry') + \
              '\n(' + message + ')'
-            dialog.error(text)
             self.goToLoginWindow()
+            self.mainWindow.showNiceBar(text,self.niceBarWarningColor, gtk.STOCK_DIALOG_WARNING)
         else:
             self.autoReconnect(self.userEmail, password, self.userStatus)
 
@@ -326,6 +342,9 @@ class Controller(gobject.GObject):
         self.pluginManager = None
 
     def on_login_successful(self, msn):
+        if self.reconnectTimerId is not None:
+            gobject.source_remove(self.reconnectTimerId)
+            self.reconnectTimerId = None
         self.connected = True
         self.pendingAvatars = {}
         self.idleTimeout = 0
@@ -351,17 +370,11 @@ class Controller(gobject.GObject):
         self.msn.connect('exception', self.on_msnp_exception)
         sys.excepthook = self.except_hook_dialog
 
-        self.contacts = ContactManager.ContactManager(
-                                dialog, self.msn, self.userEmail)
-        self.groups = GroupManager.GroupManager(
-                                dialog, self.msn)
-
+        # FIXME: strange issue with avatars
+        self.changeAvatar(self.config.user['avatarPath'])
         self.mainWindow.buildInterface('userlist')
         self.changeAvatar(self.config.user['avatarPath'])
-
-        self.config.user['autoReply'] = False
-        self.autoReplyMessage = self.config.user['autoReplyMessage']
-
+        
         layout = self.config.user['conversationLayout']
         if not self.conversationLayoutManager.load(layout):
             self.conversationLayoutManager.setDefault()
@@ -394,6 +407,10 @@ class Controller(gobject.GObject):
         self.Slash = SlashCommands.SlashCommands(self)
 
         # add here
+        if self.config.user['enableSounds'] == True:
+            self.sound = Sound.SoundHandler(self, self.msn, action='start')
+        else:
+            self.sound = Sound.SoundHandler(self, self.msn, action=None)
 
         if not TrayIcon.disabled:
             # REMEMBER to remove them when disconnect
@@ -488,6 +505,15 @@ class Controller(gobject.GObject):
         # canhastestsirkthxbai
         # self.refreshUserList()
 
+    def removeGroup(self, group):
+        #asks the user before removing the group
+        def remove_cb(response):
+            if response == stock.YES:
+                self.groups.remove(group.name)
+
+        message = _('Are you sure you want to remove this group?')
+        dialog.yes_no(message,remove_cb)
+
     def autoReconnect(self, user, password, status):
         self.mainWindow.buildInterface('reconnect')
         self.mainWindow.login.setFieldValues(user, password, status)
@@ -560,6 +586,7 @@ class Controller(gobject.GObject):
                 self.trayIcon.menu.remove(self.trayPlugins)
                 self.trayIcon.menu.remove(self.trayPreferences)
                 self.trayIcon.menu.remove(self.trayAbout)
+                self.trayIcon.menu.remove(self.sound.checkBox)
                 self.trayIcon.update('disconnected')
             except:
                 pass
@@ -638,6 +665,22 @@ class Controller(gobject.GObject):
         path_current = self.config.user['avatarPath']
         dialog.set_picture(self, path_current, avatar_cache, _on_picture_selected)
 
+    def change_profile_dialog(self):
+        '''shows a dialog to change nick, personal message and avatar'''
+
+        def responseProfile(response, nick, psm, avatarPath):
+            '''response if user accepts or denys the profile dialog'''
+            if response == stock.ACCEPT:
+                self.contacts.set_nick(nick)
+                self.contacts.set_message(psm)
+                if avatarPath != self.config.user['avatarPath']:
+                    self.changeAvatar(avatarPath)
+
+        nick=self.contacts.get_nick()
+        psm=self.contacts.get_message()
+        currentAvatarPath = self.config.user['avatarPath']
+        dialog.show_profile(self, nick, psm, currentAvatarPath, responseProfile)
+
     def changeAvatar(self, filename):
         if not self.msn:
             return
@@ -668,15 +711,22 @@ class Controller(gobject.GObject):
 
     def addUserDialog(self, toGroup=None):
         '''show a dialog requesting the email of the ser to be added'''
-        def add_contact_cb(response, account='', group=''):
+        def add_contact_cb(response, account='', group='', alias=''):
             '''callback for the add_contact dialog'''
             if response == stock.ACCEPT:
+                account = account.strip()
                 if len(account.split('@')) == 2:
-                    self.contacts.add(account, group)
+                    if group != '' and not group in self.groups.groups.keys():
+                        self.groups.add(group)
+                    self.contacts.add(account, group, *(self.delayedAlias, account, alias))
                 else:
                     dialog.warning(_("Invalid account"))
 
-        dialog.add_contact(self.groups.groups.keys(), None, add_contact_cb)
+        dialog.add_contact(self.groups.groups.keys(), None, add_contact_cb, self.theme.getImage('login'))
+
+    def delayedAlias(self, account, alias):
+        self.contacts.set_alias(account, alias)
+        return False
 
     def addNotification(self, msnp, command, tid, params, email, nick):
         '''this method is called when a user adds you'''
@@ -790,13 +840,6 @@ class Controller(gobject.GObject):
             self.mainWindow, self.config)
         p.show()
 
-    def seeSpace(self, email):
-        '''gets the space url and opens it in a browser'''
-        #self.msn.getSpaceData(email)
-        #desktop.open('http://spaces.live.com/' + user)
-        self.msn.getUserProfile(email)
-        # FIXME: get space url
-
     def seeAvatarHistory(self, email):
        '''opens a dialog with all user's avatars'''
 
@@ -828,8 +871,8 @@ class Controller(gobject.GObject):
         else:
             message = _('The server has disconnected you.')
 
-        self.mainWindow.disconectionMessage = message
         self.logout(False, False)
+        self.mainWindow.showNiceBar(message,self.tooltipColor)
 
     def getMenuData(self):
         return self.mainWindow.userList.getMenuData()
@@ -854,13 +897,12 @@ class Controller(gobject.GObject):
                 self.config.glob['binary'])
 
 def parseArgs():
-    '''parses sys.argv with getopt
-    returns tuple with Controller args'''
+    '''parses sys.argv with getopt, returns tuple with Controller args'''
     username = ''
     minimized = False
-    safe = False
     leakdebug = False
     iconified = False
+    badroot = False
 
     # parse arguments
     try:
@@ -869,15 +911,16 @@ def parseArgs():
         #getopt is disabled in emesene py2exe
         return ('', False, False, False)
 
-    shortArgs = 'm,i'
-    longArgs = ['iconified','minimized', 'user=', 'safe', 'leakdebug']
+    shortArgs = 'm,i,f'
+    longArgs = ['iconified', 'minimized', 'user=', 'fast-login', 'leakdebug', 
+                'i-know-that-running-emesene-as-root-is-bad']
     try:
         args = getopt.getopt(sys.argv[1:], shortArgs, longArgs)
     except getopt.GetoptError, e:
         # wrong input, display usage
         print e
         print 'Usage:', sys.argv[0], '[-m|--minimized] | [-i | --iconified] [--user=mail@address]'
-        print 'Advanced options: --safe, --leakdebug'
+        print 'Advanced options: [-f|--fast-login], --leakdebug, --i-know-that-running-emesene-as-root-is-bad'
         sys.exit(1)
 
     # parse getopt output
@@ -889,33 +932,42 @@ def parseArgs():
         else:
             if key == '-i' or key == '--iconified':
                 iconified = True
-        if key == '--safe':
-            safe = True
         if key == '--leakdebug':
             leakdebug = True
+        if key == '--i-know-that-running-emesene-as-root-is-bad':
+            badroot = True
 
-    return (username, minimized, safe, leakdebug, iconified)
+    return (username, minimized, leakdebug, iconified, badroot)
 
 def debug(msg):
     '''print a debug message'''
     print 'Controller: ' + msg
 
 def main():
-    if os.name == 'posix' and os.getuid() == 0:
-        print "I refuse to run as root"
+    args = parseArgs()
+    if (os.name == 'posix') and (os.getuid() == 0) and (args[5] == False):
+        print "I refuse to run as root. " \
+              "If you know the risks and still want to do it," \
+              " just add the --i-know-that-running-emesene-as-root-is-bad option."
         return
+    
+    if (os.name != 'nt'):
+        try:
+            path = os.path.dirname(__file__) or sys.path[0]
+        except NameError:
+            path = sys.path[0]
+    else:
+        path = os.path.dirname(sys.path[0])
 
-    try:
-        path = os.path.dirname(__file__) or sys.path[0]
-    except NameError:
-        path = sys.path[0]
-
+    gtk.settings_get_default().set_property("gtk-error-bell", False)
     originalPath = os.getcwd()
     os.chdir(path)
     sys.path.append(path)
     # start controller
-    controller = Controller(*parseArgs())
-    
+    if (os.name == 'nt') and (hasattr(sys, "frozen")):
+        controller = Controller('', *args)    
+    else:
+        controller = Controller(*args)
     gobject.threads_init()
     # this stuff is to interrupt blocking stuff safely.
     for i in range(5):
