@@ -67,6 +67,9 @@ class Conversation(gobject.GObject):
         self.theme = controller.theme
         self.parentConversationWindow = None
         
+        self.enabledEncrypt = False
+        self.encoderDecoder = None
+        
         # do this for automagic reconnection if user comes online 
         # and there's no avail switchboard
         self.userMail = self.switchboard.firstUser
@@ -110,6 +113,8 @@ class Conversation(gobject.GObject):
         self.ui.transfers.show_all()
         if self.config.user['autoAcceptTransfer']:
             ft.accept()
+               
+        self.ui.scrollToBottom(force=True)
             
     def sendWebcam(self):
         '''This send a request to send your webcam to the user'''
@@ -337,6 +342,8 @@ class Conversation(gobject.GObject):
         nick = self.controller.msn.getUserDisplayName(mail)
         self.appendOutputText(None, _("%s just sent you a nudge!")% \
           self.parser.getParser(nick).get(False), 'information')
+        
+        self.ui.lastMessageReceivedAt()
         self.doMessageWaiting(mail)
 
     def receive_wink(self, switchboard, mail, msnobj):
@@ -349,6 +356,7 @@ class Conversation(gobject.GObject):
         self.appendOutputText(None, _("%(nick)s sent you a wink: %(name)s") % \
             {'nick': nick, 'name': name}, 'information')
 
+        self.ui.lastMessageReceivedAt()
         self.doMessageWaiting(mail)
 
     def receiveOIM(self, nick, message, date):
@@ -361,6 +369,7 @@ class Conversation(gobject.GObject):
         '''This method is called when a error message is received'''
         self.appendOutputText('Error', "Can\'t send message (%err)\n%(mess)" % \
             (error, message), 'error')
+        self.ui.lastMessageReceivedAt()
         self.doMessageWaiting('')
 
     def onReceiveMessage(self, switchboard, mail, nick, message,
@@ -368,13 +377,15 @@ class Conversation(gobject.GObject):
         '''This method is called when a message is received in the switchboard'''
         self.controller.conversationManager.emit('receive-message', self, \
             mail, nick, message, format, charset, hasp4)
+        self.ui.lastMessageReceivedAt()
 
     def onInkMessage(self, switchboard, mail, filename):
         '''This method is called when an ink message is received
         in the switchboard'''
+        self.appendOutputText(mail, quote(filename), 'ink_incoming')
 
         self.doMessageWaiting(mail)
-        self.appendOutputText(mail, quote(filename), 'ink_incoming')
+        self.ui.lastMessageReceivedAt()
 
     def doMessageWaiting(self, mail):
         self.hasMessageWaiting = True
@@ -389,29 +400,28 @@ class Conversation(gobject.GObject):
             self.parentConversationWindow.show()
         else:
             self.ui.setDefault(mail)
-
+            
     def do_receive_message(self, mail, nick, message, format, charset, p4c):
         '''This method is called when a message is received
         in the switchboard'''
-        self.doMessageWaiting(mail)
-
         if self.config.user['autoReply'] and not self.autoreplySent:
             msg = self.config.user['autoReplyMessage']
 
             # no gettext here, it's a semi standard way
             # to identify automessages
-            self.switchboard.sendMessage('AutoMessage: ' + msg)
-            self.appendOutputText(None, 'AutoMessage: %s\n' % msg, \
+            self.switchboard.sendMessage(_('AutoMessage: ') + msg)
+            self.appendOutputText(None, _('AutoMessage: %s\n') % msg, \
                 'information')
             self.autoreplySent = True
-
-        if message is not None:
-            if p4c: # give p4context name instead of mail
-                self.appendOutputText(nick, message, 'incoming', p4c, \
-                    self.parseFormat(mail, format))
-            else:
-                self.appendOutputText(mail, message, 'incoming', p4c, \
-                    self.parseFormat(mail, format))
+        if message is None:
+            return
+                    
+        if p4c: # give p4context name instead of mail
+            self.appendOutputText(nick, message, 'incoming', p4c, self.parseFormat(mail, format))
+        else:
+            self.appendOutputText(mail, message, 'incoming', p4c, self.parseFormat(mail, format))
+                       
+        self.doMessageWaiting(mail)
             
     def userJoin(self, switchboard, mail):
         '''This method is called when someone joins the conversation'''
@@ -430,9 +440,13 @@ class Conversation(gobject.GObject):
 
     def userLeave(self, switchboard, mail):
         '''method called when someone leaves the conversation'''
+        if len(self.getMembers()) == 1:
+            # please, don't annoy the user in a single chat
+            return
+
         nick = self.controller.msn.getUserDisplayName(mail)
         nick = self.parser.getParser(nick).get(False)
-        self.appendOutputText('', _("%s has left the conversation")%nick, \
+        self.appendOutputText('', _("%s has left the conversation") % nick, \
             'information')
 
         if self.isCurrent:
@@ -478,16 +492,17 @@ class Conversation(gobject.GObject):
 
         user = self.getMembers()[0]
         self.setSwitchboard(self.controller.msn.getSwitchboard(user))
+        msn = self.switchboard.msn
+        msn.connect('user-attr-changed', self.onUserAttrChanged)
+        msn.connect('custom-emoticon-transfered', self.onCustomEmoticonTransfered)
         self.autoreplySent = False
 
-
     def do_send_message(self, message, retry=0):
         '''Send the message from the UI input. This chooses between OIM and
         switchboard to send the message.'''
-
         remoteMail = self.switchboard.firstUser
         remoteStatus = self.controller.contacts.get_status(remoteMail)
-
+        
         def do_send_offline(response, mail='', message=''):
             '''callback for the confirm dialog asking to send offline
             message'''
@@ -495,14 +510,18 @@ class Conversation(gobject.GObject):
             self.switchboard.msn.msnOIM.send(mail, message)
             self.appendOutputText(self.user, message, 'outgoing')
 
-        if self.switchboard.status == 'error' and remoteStatus == 'FLN':
+        if self.switchboard.status == 'error' and \
+            (remoteStatus == 'FLN' or remoteStatus == 'HDN'):
             do_send_offline(stock.YES, remoteMail, message)
             return
 
         if self.switchboard.status == 'closed':
             self.reconnect()
-
+            self.do_send_message(message)
+            return
+            
         messageChunks = splitMessage(message)
+
         for chunk in messageChunks:
             try:
                 # why is conversation sending custom emoticons manually?
@@ -531,7 +550,7 @@ class Conversation(gobject.GObject):
         if self.closed:
             return False
         elif self.switchboard.status == 'established':
-            self.switchboard.sendMessage('', '', 'text/x-keep-alive', 'A')
+            self.switchboard.sendKeepAlive()
             return True
         
         return False
@@ -688,7 +707,7 @@ class Conversation(gobject.GObject):
             print e
 
         if self.ui.textview.get_buffer().get_has_selection() == False:
-            self.ui.scrollToBottom()
+            self.ui.scrollToBottom(force=True)
 
     def statusChanged(self, *args):
         if self.switchboard and self.ui:
