@@ -19,12 +19,14 @@
 import gtk
 import time
 import pango
+import shutil
 import gobject
 import FilterEntry
 
 # for drag and drop
 import os
 import urllib
+import re
 # for webcam errors
 import dialog
 
@@ -37,14 +39,20 @@ from Parser import PangoDataType
 from Parser import UserListDataType
 from SmileyRenderer import SmileyLabel
 
-import emesenelib.common
 import emesenelib.ContactData
 
 import Widgets
 
 from htmltextview import HtmlTextView
 
-#import SmoothScrolledWindow
+class OurStatusBar(gtk.Statusbar):
+    def __init__(self, ui):    
+        gtk.Statusbar.__init__(self)
+        self.ui = ui
+        # this hack skips the statusbar stack
+        self.label = self.get_children()[0].get_children()[0]
+    def set_text(self, text):
+        self.label.set_text(text)
 
 class ConversationUI(gtk.VBox):
     '''this class represent all the widgets that are inside a tab
@@ -73,7 +81,7 @@ class ConversationUI(gtk.VBox):
             parentConversation.isCurrent, avatarRight)
         self.input.show()
         # the status bar
-        self.status = gtk.Statusbar()
+        self.status = OurStatusBar(self)
 
         # the list of users when we are on a group chat
         self.listOfUsers = UserList.UserList(self.controller, \
@@ -85,9 +93,6 @@ class ConversationUI(gtk.VBox):
         self.scrollList.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.scrollList.add(self.listOfUsers)
 
-        # the scroll for the textview below
-        # self.scroll = SmoothScrolledWindow.SmoothScrolledWindow()
-        # bugged with new custom animated emoticon handling
         self.scroll = gtk.ScrolledWindow()
         self.scroll.set_shadow_type(gtk.SHADOW_IN)
         self.scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -109,12 +114,16 @@ class ConversationUI(gtk.VBox):
         self.eventBox.set_size_request(0, 30)
         self.eventBox.add(box)
         self.eventBox.modify_bg(gtk.STATE_NORMAL, self.controller.tooltipColor)
+        self.eventBox.connect("button-press-event", self.hideEventBox)
         self.label = gtk.Label(_("Connecting..."))
         self.label.set_ellipsize(pango.ELLIPSIZE_END)
         image = gtk.Image()
         image.set_from_stock (gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_LARGE_TOOLBAR)
         box.pack_start(image, False, False, 5)
         box.pack_start(self.label, True, True, 5)
+        self.hiddenByUser = False #user can "close" the event box by clicking the bar
+                                  #this should prevent the bar from reappearing everytime
+                                  #that the window is redraw
 
         # pack the scroll with the status bar
         self.mainBox = gtk.VBox(False, 0)
@@ -181,6 +190,7 @@ class ConversationUI(gtk.VBox):
         self.closed = False
 
         self.last_mark = None
+        self.lastTimestamp = 0
 
         self.show()
         self.update()
@@ -188,7 +198,7 @@ class ConversationUI(gtk.VBox):
     def onInputResize(self, pane, gparamspec, *args):
         # If the position of the seperator changed, scroll to bottom
         if gparamspec.name == 'position':
-            self.scrollToBottom()
+            self.scrollToBottom(force=True)
 
     def onInputResizeCompleted(self, widget, event, *args):
         # save the height of the input box to config
@@ -210,6 +220,10 @@ class ConversationUI(gtk.VBox):
         self.input.input.emit('key-press-event', event)
         self.input.grabFocus()
 
+    def hideEventBox(self, widget, event):
+        self.hiddenByUser = True
+        self.eventBox.hide_all()
+
     def close(self):
         self.closed = True
 
@@ -248,7 +262,7 @@ class ConversationUI(gtk.VBox):
         # updates local and remote avatars or contact list
         if isGroupChat:
             members = self.parentConversation.getMembersDict()
-            d = {'members' : emesenelib.ContactData.Group('members')}
+            d = {'members' : emesenelib.ContactData.Group(_('Members'))}
             for member in members.values():
                 d['members'].setUser(member.email, member)
 
@@ -299,9 +313,23 @@ class ConversationUI(gtk.VBox):
         self.scrollList.set_size_request(scrollListWidth, 0)
 
         self.update_eventbox()
+
+	    # Fixes the focus bug in Karmic, i know it's ugly but..
+        # http://www.daa.com.au/pipermail/pygtk/2007-December/014660.html
+        gobject.timeout_add(0, self.grabInputFocus)        
+
+    def grabInputFocus(self, args=None):
+        ''' grabs the focus only if the conversation is "active" '''
+        if self.input.get_property('has_focus'): return False
+        cw = self.parentConversation.parentConversationWindow
+        if not cw: return False
+        tabs = cw.tabs
+        if tabs.get_current_page() == tabs.page_num(self):
+            self.input.grabFocus()
+        return False
         
     def update_eventbox(self):
-        if self.parentConversation.switchboard.status == 'error':
+        if self.parentConversation.switchboard.status == 'error' and not self.hiddenByUser:
             self.label.set_text(\
                 _("User is offline, messages will be sent as offline messages"))
             self.eventBox.show_all()
@@ -310,12 +338,14 @@ class ConversationUI(gtk.VBox):
         elif self.parentConversation.switchboard.status != 'established':
             # we should be connecting, we show the stuff only if
             # this connection is way looooooong
-            gobject.timeout_add(5000, self.set_label_as_connecting)    
+            gobject.timeout_add(5000, self.set_label_as_connecting)
         else: # self.parentConversation.switchboard.status == 'established'
+            self.hiddenByUser = False
             self.eventBox.hide()
     
     def set_label_as_connecting(self):
         if self.parentConversation.switchboard.status == 'connected':
+            self.hiddenByUser = False
             self.label.set_text(_("Connecting..."))
             self.eventBox.show_all()        
         return False
@@ -330,9 +360,9 @@ class ConversationUI(gtk.VBox):
             preventTime = 3000
         gobject.timeout_add(preventTime, self.update_eventbox)
 
-    def scrollToBottom(self):
+    def scrollToBottom(self, force=False):
         '''scroll to the end of the conversation'''
-        self.textview.scrollToBottom()
+        self.textview.scrollToBottom(force)
 
     def showUserList(self):
         self.scrollList.show_all()
@@ -360,7 +390,7 @@ class ConversationUI(gtk.VBox):
                 else:
                     contact = self.controller.getContact(mail)
                     if contact:
-                        parts = self.parser.getParser(contact.nick).get()
+                        parts = self.parser.getParser(contact.nick).get(escaped=False)
                         for part in parts:
                             string += str(part)
                     else:
@@ -375,12 +405,10 @@ class ConversationUI(gtk.VBox):
             else:
                 string += ' ' + _('are typing a message...')
 
-        try:
-            # this is a hack to skip the statusbar stack
-            self.status.get_children()[0].get_children()[0]\
-                .set_text(emesenelib.common.unescape(string))
-        except: # and this is a hack because now we kill conversation.ui
-            pass# and sometimes this gets called somehow random.
+            try:
+                self.status.set_text(string)
+            except: # and this is a hack because now we kill conversation.ui
+                pass# and sometimes this gets called somehow random.
             
     def setMessageWaiting(self, mail):
         if self.parentConversation.isCurrent:
@@ -415,8 +443,36 @@ class ConversationUI(gtk.VBox):
         else:
             self.setDefault(mail)
         self.contactTyping[mail] = False
+
+        self.typingTimeoutID = 0
+        if self.config.user['showLastMessageReceivedAt']:
+            self.setTimestampStatusText()
+        else: # clean "user is typing" stuff, if timestamp isn't wanted
+            try: 
+                self.status.set_text("")
+            except:
+                pass        
         return False
 
+    def lastMessageReceivedAt(self):
+        self.lastTimestamp = time.strftime('%X', time.localtime())
+        if self.config.user['showLastMessageReceivedAt']:
+            self.setTimestampStatusText()
+        else:# clean "user is typing" stuff, if timestamp isn't wanted
+            try: 
+                self.status.set_text("")
+            except:
+                pass
+
+    def setTimestampStatusText(self):
+        # see other occurence of this in this code, it's hacky
+        if self.lastTimestamp == 0: return
+        string = (_('Last message received at: %s') % self.lastTimestamp)
+        try:
+            self.status.set_text(string)
+        except: # and this is a hack because now we kill conversation.ui
+            pass# and sometimes this gets called somehow random.
+
     def setDefault(self, mail):
         self.tabWidget.setDefault()
         self.header.setDefault()
@@ -461,10 +517,7 @@ class Header(gtk.HBox):
         self.btn_ask_webcam.connect('clicked', self.ask_webcam_clicked)
         self.user = self.controller.getContact(\
             self.parentUI.parentConversation.getMembers()[0])
-
-        tooltips = gtk.Tooltips()
-        tooltips.set_tip(self.btn_ask_webcam, _('View webcam'))
-        tooltips.enable()
+        self.btn_ask_webcam.set_tooltip_text(_('View webcam'))
 
         if self.user.shares_webcam():
             self.btn_ask_webcam.show()
@@ -579,9 +632,11 @@ class Header(gtk.HBox):
             status = self.controller.status_ordered[2][status]
 
             # btw, styleOpen/styleClose is ignored, didn't find a good way to handle it
-            args = {'email':contact.email, 'status':status,
-                    'nick':contact.nick,  'pm':contact.personalMessage,
-                    'color':personalMessageColor}
+            args = {'email' : contact.email, 
+                    'status' : status,
+                    'nick' : contact.nick.replace('\n', ' '),
+                    'pm' : contact.personalMessage.replace('\n', ' '),
+                    'color' : personalMessageColor}
 
             try:
                 # load the template from config
@@ -610,7 +665,7 @@ class Header(gtk.HBox):
         elif len(members) > 1:
             self.output = styleOpen + _('Group chat') + styleClose + \
                 "\n<span foreground='%s'>" % personalMessageColor + \
-                str(len(members)) + ' ' + _('Members') + "</span>"
+                str(len(members)) + ' ' + _('members') + "</span>"
 
             self.statusImage.set_from_pixbuf(
                 self.controller.theme.getImage('groupChat') )
@@ -727,9 +782,15 @@ class AvatarHBox(gtk.HBox):
         self.hidebutton.connect('clicked', self.hideShowButton)
         self.hidebutton.set_relief(gtk.RELIEF_NONE)
         if self.config.user['avatarsOnRight']:
-            self.hidebuttonArrow = Widgets.TinyArrow(gtk.ARROW_RIGHT)
+#            self.hidebuttonArrow = Widgets.TinyArrow(gtk.ARROW_RIGHT)
+            self.hidebuttonArrow = gtk.Arrow(gtk.ARROW_RIGHT,gtk.SHADOW_NONE)
+            self.hidebuttonArrow.set_alignment(1,0.5)
+            self.hidebuttonArrow.set_size_request(-1,10)
         else:
-            self.hidebuttonArrow = Widgets.TinyArrow(gtk.ARROW_LEFT)
+            self.hidebuttonArrow = gtk.Arrow(gtk.ARROW_LEFT,gtk.SHADOW_NONE)
+            self.hidebuttonArrow.set_alignment(0,0.5)
+            self.hidebuttonArrow.set_size_request(-1,10)
+#            self.hidebuttonArrow = Widgets.TinyArrow(gtk.ARROW_LEFT)
         self.hidebutton.add(self.hidebuttonArrow)
 
         self.image = Widgets.avatarHolder(cellKeyPosition=gtk.ANCHOR_SOUTH)
@@ -739,13 +800,27 @@ class AvatarHBox(gtk.HBox):
         self.imageEventBox.add(self.image)
 
         self.updateDisplayPicture()
+        self.menu = gtk.Menu()                                  
+        setAvatarMenuItem = self.newImageMenuItem(_("Set as your _avatar"), \
+            gtk.STOCK_ADD)                                                 
+        saveAsMenuItem = self.newImageMenuItem(_("_Save image as"), \
+            gtk.STOCK_SAVE_AS)                                             
+        self.menu.append(setAvatarMenuItem)                                
+        self.menu.append(saveAsMenuItem)                                   
+        setAvatarMenuItem.connect("activate", self.on_set_yours)           
+        saveAsMenuItem.connect("activate", self.on_save_as)                
+        setAvatarMenuItem.show()                                           
+        saveAsMenuItem.show()   
+        
         # if we have an email, this is our contact's avatar
         if mail:
             self.controller.msn.connect('display-picture-changed',
                 self.onDisplayPictureChanged)
             self.controller.msn.connect('user-attr-changed',
                 self.onDisplayPictureChanged)
-
+            self.imageEventBox.connect('button-press-event', \
+                self.button_clicked)  
+                
             self.key = 'showAvatarOther'
         else:
             # we don't have an email, so this is our avatar
@@ -796,6 +871,28 @@ class AvatarHBox(gtk.HBox):
             else:
                 self.hidebuttonArrow.set(gtk.ARROW_LEFT, gtk.SHADOW_NONE)
 
+    def button_clicked(self, widget, event):                                         
+        if len(self.parentUI.parentConversation.getMembersDict()) == 1:              
+            self.menu.popup(None, None, None, event.button, event.time, None)        
+                                                                                     
+    def on_set_yours(self, *args):                                                   
+        contact = self.controller.getContact(self.mail)                              
+        imagePath = os.path.join(self.config.getCachePath(), \
+            contact.displayPicturePath)                                              
+        self.controller.changeAvatar(imagePath)                                      
+                                                                                     
+    def on_save_as(self, *args):                                                     
+        contact = self.controller.getContact(self.mail)                              
+        imagePath = os.path.join(self.config.getCachePath(), \
+            contact.displayPicturePath)                                              
+                                                                                     
+        dialog = gtk.FileChooserDialog(_('Save image as'),action=gtk.FILE_CHOOSER_ACTION_SAVE,
+            buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))    
+        dialog.set_current_name(os.path.split(imagePath)[1]+".png")                           
+        if dialog.run() == gtk.RESPONSE_OK:                                                   
+            shutil.copy2(imagePath, dialog.get_filename())                                    
+        dialog.destroy()                                                                      
+
     def updateDisplayPicture(self):
         if self.mail:
             contact = self.controller.getContact(self.mail)
@@ -823,7 +920,20 @@ class AvatarHBox(gtk.HBox):
         if self.config.user['showAvatars']:
             self.config.user[self.key] = not self.config.user[self.key]
         self.update()
-
+        
+    def newImageMenuItem(self, label, stock=None, img=None, animation=None):                  
+        mi = gtk.ImageMenuItem(_(label))                                                      
+        if stock:                                                                             
+            mi.set_image(gtk.image_new_from_stock(stock, gtk.ICON_SIZE_MENU))                 
+        elif img:                                                                             
+            image = gtk.Image()                                                               
+            image.set_from_pixbuf(img)                                                        
+            mi.set_image(image)                                                               
+        elif animation:                                                                       
+            image = gtk.Image()                                                               
+            image.set_from_animation(animation)                                               
+            mi.set_image(image)                                                               
+        return mi     
 
 class InputWidget(gtk.HBox):
     '''This class represents the input widgets (text entry) and avatar (if enabled)'''
@@ -1026,7 +1136,7 @@ class InputWidget(gtk.HBox):
 
     def grabFocus(self):
         self.input.grab_focus()
-
+        
     def clearMessageInput(self):
         self.setInputText('')
         return True
@@ -1244,11 +1354,14 @@ class InputWidget(gtk.HBox):
     def get_file_path_from_dnd_dropped_uri(self, uri):
         '''Parses an URI received from dnd and return the real path'''
 
-        path = urllib.url2pathname(uri) # escape special chars
+        if os.name != 'nt':
+            path = urllib.url2pathname(uri) # escape special chars
+        else:
+            path = urllib.unquote(uri) # escape special chars
         path = path.strip('\r\n\x00') # remove \r\n and NULL
 
         # get the path to file
-        if path.startswith('file:\\\\\\'): # windows
+        if re.match('^file:///[a-zA-Z]:/', path): # windows
             path = path[8:] # 8 is len('file:///')
         elif path.startswith('file://'): # nautilus, rox
             path = path[7:] # 7 is len('file://')
@@ -1297,164 +1410,171 @@ class ToolbarWidget(gtk.Toolbar):
                                                         self.controller, \
                                                        self.parentUI)
 
-        #self.fontFace = gtk.ToolButton()
-        #self.fontFace.set_stock_id(gtk.STOCK_SELECT_FONT)
-        #self.fontFace.connect('clicked', self.on_font_face_clicked)
-
         #font face
-        self.fontFace = gtk.ToolButton()
-        if self.controller.theme.getImage('fontface'):
+        separator = False
+        if self.config.user['toolFontType']:
+            self.fontFace = gtk.ToolButton()
+            if self.controller.theme.getImage('fontface'):
                 fontfaceicon = gtk.Image()
                 fontfaceicon.set_from_pixbuf(self.controller.theme.getImage('fontface'))
                 self.fontFace.set_icon_widget(fontfaceicon)
-        else:
+            else:
                 self.fontFace.set_stock_id(gtk.STOCK_SELECT_FONT)
-        self.fontFace.connect('clicked', self.on_font_face_clicked)
+            self.fontFace.connect('clicked', self.on_font_face_clicked)
+            self.insert(self.fontFace, -1)
+            self.fontFace.set_tooltip_text(_('Font selection'))
+            separator = True
+        else:
+            self.fontFace = None
 
-        #self.fontColor = gtk.ToolButton()
-        #self.fontColor.set_stock_id(gtk.STOCK_SELECT_COLOR)
-        #self.fontColor.connect('clicked', self.on_font_color_clicked)
-        
         #font color
-        self.fontColor = gtk.ToolButton()
-        if self.controller.theme.getImage('fontcolor'):
+        if self.config.user['toolFontColor']:
+            self.fontColor = gtk.ToolButton()
+            if self.controller.theme.getImage('fontcolor'):
                 fontcoloricon = gtk.Image()
                 fontcoloricon.set_from_pixbuf(self.controller.theme.getImage('fontcolor'))
                 self.fontColor.set_icon_widget(fontcoloricon)
-        else: 
+            else:
                 self.fontColor.set_stock_id(gtk.STOCK_SELECT_COLOR)
-        self.fontColor.connect('clicked', self.on_font_color_clicked)
-
-        #self.fontStyleButton = gtk.ToolButton()
-        #self.fontStyleButton.set_label(_('Fontstyle'))
-        #self.fontStyleButton.set_stock_id(gtk.STOCK_BOLD)
-        #self.fontStyleButton.connect('clicked', self.showFontStyleWindow)
+            self.fontColor.connect('clicked', self.on_font_color_clicked)
+            self.insert(self.fontColor, -1)
+            self.fontColor.set_tooltip_text(_('Font color selection'))
+            separator = True
+        else:
+            self.fontColor = None
 
         #font style button
-        self.fontStyleButton = gtk.ToolButton()
-        self.fontStyleButton.set_label(_('Fontstyle'))
-        if self.controller.theme.getImage('fontstyle'):
+        if self.config.user['toolFontStyle']:
+            self.fontStyleButton = gtk.ToolButton()
+            self.fontStyleButton.set_label(_('Fontstyle'))
+            if self.controller.theme.getImage('fontstyle'):
                 fonticon = gtk.Image()
                 fonticon.set_from_pixbuf(self.controller.theme.getImage('fontstyle'))
                 self.fontStyleButton.set_icon_widget(fonticon)
-        else: 
+            else: 
                 self.fontStyleButton.set_stock_id(gtk.STOCK_BOLD)
-        self.fontStyleButton.connect('clicked', self.showFontStyleWindow)
+            self.fontStyleButton.connect('clicked', self.showFontStyleWindow)
+            self.insert(self.fontStyleButton, -1)
+            self.fontStyleButton.set_tooltip_text(_('Font styles'))
+            separator = True
+        else:
+            self.fontStyleButton = None
 
-        #self.smilieButton = gtk.ToolButton()
-        #self.smilieButton.set_label(_('Smilie'))
-        #self.smilieButton.connect('clicked', self.showSmilieWindow)
+        if separator:
+            self.insert(gtk.SeparatorToolItem(), -1)
+        separator = False
 
         #smilie button, fixed for mac4lin
-        smilieicon = gtk.Image()
-        smilieicon.set_from_pixbuf(self.controller.theme.getImage('smilie'))
-        self.smilieButton = gtk.ToolButton(smilieicon, _('Smilie'))
-        self.smilieButton.connect('clicked', self.showSmilieWindow)
-
-        #self.nudgeButton = gtk.ToolButton()
-        #self.nudgeButton.set_label(_('Nudge'))
-        #self.nudgeButton.connect('clicked', self.doNudge)
+        if self.config.user['toolSmilies']:
+            smilieicon = gtk.Image()
+            smilieicon.set_from_pixbuf(self.controller.theme.getImage('smilie'))
+            self.smilieButton = gtk.ToolButton(smilieicon, _('Smilie'))
+            self.smilieButton.connect('clicked', self.showSmilieWindow)
+            self.insert(self.smilieButton, -1)
+            self.smilieButton.set_tooltip_text(_('Insert a smilie'))
+            separator = True
+        else:
+            self.smilieButton = None
 
         #nudge button, fixed for mac4lin
-        nudgeicon = gtk.Image()
-        nudgeicon.set_from_pixbuf(self.controller.theme.getImage('nudge'))
-        self.nudgeButton = gtk.ToolButton(nudgeicon, _('Nudge'))
-        self.nudgeButton.connect('clicked', self.doNudge)
+        if self.config.user['toolNudge']:
+            nudgeicon = gtk.Image()
+            nudgeicon.set_from_pixbuf(self.controller.theme.getImage('nudge'))
+            self.nudgeButton = gtk.ToolButton(nudgeicon, _('Nudge'))
+            self.nudgeButton.connect('clicked', self.doNudge)
+            self.insert(self.nudgeButton, -1)
+            self.nudgeButton.set_tooltip_text(_('Send nudge'))
+            separator = True
+        else:
+            self.nudgeButton = None
 
-        #self.inviteButton = gtk.ToolButton()
-        #self.inviteButton.set_label(_('Invite'))
-        #self.inviteButton.set_stock_id(gtk.STOCK_ADD)
-        #self.inviteButton.connect('clicked', self.showInviteDialog)
+        if separator:
+            self.insert(gtk.SeparatorToolItem(), -1)
+        separator = False
 
         #invite button
-        self.inviteButton = gtk.ToolButton()
-        self.inviteButton.set_label(_('Invite'))
-        if self.controller.theme.getImage('invite'):
+        if self.config.user['toolInvite']:
+            self.inviteButton = gtk.ToolButton()
+            self.inviteButton.set_label(_('Invite'))
+            if self.controller.theme.getImage('invite'):
                 inviteicon = gtk.Image()
                 inviteicon.set_from_pixbuf(self.controller.theme.getImage('invite'))
                 self.inviteButton.set_icon_widget(inviteicon)
-        else:
+            else:
                 self.inviteButton.set_stock_id(gtk.STOCK_ADD)
-        self.inviteButton.connect('clicked', self.showInviteDialog)
-
-        #imgclear = gtk.Image()
-        #imgclear.set_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        #self.clearButton = gtk.ToolButton(imgclear, _('Clear Conversation'))
-        #self.clearButton.connect('clicked', self.clearOutputText)
-
-        #clear conversation toolbar button
-        imgclear = gtk.Image()
-        if self.controller.theme.getImage('clear'):
-                imgclear.set_from_pixbuf(self.controller.theme.getImage('clear'))
+            self.inviteButton.connect('clicked', self.showInviteDialog)
+            self.insert(self.inviteButton, -1)
+            self.inviteButton.set_tooltip_text( \
+                _('Invite a friend to the conversation'))
+            separator = True
         else:
-                imgclear.set_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        self.clearButton = gtk.ToolButton(imgclear, _('Clear Conversation'))
-        self.clearButton.connect('clicked', self.clearOutputText)
-
-        #self.sendfileButton = gtk.ToolButton()
-        #self.sendfileButton.set_label(_('Send File'))
-        #self.sendfileButton.set_stock_id(gtk.STOCK_GOTO_TOP)
-        #self.sendfileButton.connect('clicked', self.sendFileClicked)
+            self.inviteButton = None
 
         #send a file
-        self.sendfileButton = gtk.ToolButton()
-        self.sendfileButton.set_label(_('Send File'))
-        if self.controller.theme.getImage('sendfile'):
+        if self.config.user['toolSendFile']:
+            self.sendfileButton = gtk.ToolButton()
+            self.sendfileButton.set_label(_('Send File'))
+            if self.controller.theme.getImage('sendfile'):
                 imgsendfile = gtk.Image()
                 imgsendfile.set_from_pixbuf(self.controller.theme.getImage('sendfile'))
                 self.sendfileButton.set_icon_widget(imgsendfile)
-        else:
+            else:
                 self.sendfileButton.set_stock_id(gtk.STOCK_GOTO_TOP)
-        self.sendfileButton.connect('clicked', self.sendFileClicked)
+            self.sendfileButton.connect('clicked', self.sendFileClicked)
+            self.insert(self.sendfileButton, -1)
+            self.sendfileButton.set_tooltip_text(_('Send a file'))
+            separator = True
+        else:
+            self.sendfileButton = None
 
         # webcam send hax
-        camicon = gtk.Image()
-        camicon.set_from_pixbuf(self.controller.theme.getImage('cam'))
-        self.sendWebcamButton = gtk.ToolButton(camicon, _('Send Webcam'))
-        self.sendWebcamButton.connect('clicked', self.sendWebcamClicked)
+        if self.config.user['toolWebcam']:
+            camicon = gtk.Image()
+            camicon.set_from_pixbuf(self.controller.theme.getImage('cam'))
+            self.sendWebcamButton = gtk.ToolButton(camicon, _('Send Webcam'))
+            self.sendWebcamButton.connect('clicked', self.sendWebcamClicked)
+            self.insert(self.sendWebcamButton, -1)
+            self.sendWebcamButton.set_tooltip_text(_('Send your Webcam'))
+            separator = True
+        else:
+            self.sendWebcamButton = None
+
+        if separator:
+            self.insert(gtk.SeparatorToolItem(), -1)
+        separator = False
+
+        #clear conversation toolbar button
+        if self.config.user['toolClear']:
+            imgclear = gtk.Image()
+            if self.controller.theme.getImage('clear'):
+                imgclear.set_from_pixbuf(self.controller.theme.getImage('clear'))
+            else:
+                imgclear.set_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_LARGE_TOOLBAR)
+            self.clearButton = gtk.ToolButton(imgclear, _('Clear Conversation'))
+            self.clearButton.connect('clicked', self.clearOutputText)
+            self.insert(self.clearButton, -1)
+            self.clearButton.set_tooltip_text(_('Clear conversation'))
+            separator = True
+        else:
+            self.clearButton = None
+
+        if separator:
+            self.insert(gtk.SeparatorToolItem(), -1)
+        separator = False
+
+        #remove the last separator
+        count = self.get_n_items()
+        item = self.get_nth_item(count-1)
+        if isinstance(item, gtk.SeparatorToolItem):
+            self.remove(item)
 
         # ENABLE THIS IF YOU IMPLEMENT INKDRAW P2P STACK
         #self.inkdrawButton = gtk.ToolButton()
         #self.inkdrawButton.set_label(_('Send Ink'))
         #self.inkdrawButton.set_stock_id(gtk.STOCK_EDIT)
         #self.inkdrawButton.connect('clicked', self.inkDrawClicked)
-
-        # Add buttons to the toolbar
-        self.insert(self.fontFace, -1)
-        self.insert(self.fontColor, -1)
-        self.insert(self.fontStyleButton, -1)
-
-        self.insert(gtk.SeparatorToolItem(), -1)
-
-        self.insert(self.smilieButton, -1)
-        self.insert(self.nudgeButton, -1)
-
-        self.insert(gtk.SeparatorToolItem(), -1)
-
-        self.insert(self.inviteButton, -1)
-        self.insert(self.sendfileButton, -1)
-        self.insert(self.sendWebcamButton, -1)
         #self.insert(self.inkdrawButton, -1)
 
-        self.insert(gtk.SeparatorToolItem(), -1)
-
-        self.insert(self.clearButton, -1)
-
-        # Set tooltips to buttons
-        self.tooltips = gtk.Tooltips()
-        self.tooltips.enable()
-
-        self.fontFace.set_tooltip(self.tooltips, _('Font selection'))
-        self.fontColor.set_tooltip(self.tooltips, _('Font color selection'))
-        self.fontStyleButton.set_tooltip(self.tooltips, _('Font styles'))
-        self.smilieButton.set_tooltip(self.tooltips, _('Insert a smilie'))
-        self.nudgeButton.set_tooltip(self.tooltips, _('Send nudge'))
-        self.inviteButton.set_tooltip(self.tooltips, \
-            _('Invite a friend to the conversation'))
-        self.clearButton.set_tooltip(self.tooltips, _('Clear conversation'))
-        self.sendfileButton.set_tooltip(self.tooltips, _('Send a file'))
-        self.sendWebcamButton.set_tooltip(self.tooltips, _('Send your Webcam'))
-
         self.show_all()
 
     def setFontBold(self, value):
@@ -1495,8 +1615,10 @@ class ToolbarWidget(gtk.Toolbar):
                 nudge = resizePixbuf(nudge, *gtk.icon_size_lookup(size))
                 imgSmilie.set_from_pixbuf(grin)
                 imgNudge.set_from_pixbuf(nudge)
-                self.smilieButton.set_icon_widget(imgSmilie)
-                self.nudgeButton.set_icon_widget(imgNudge)
+                if self.smilieButton:
+                    self.smilieButton.set_icon_widget(imgSmilie)
+                if self.nudgeButton:
+                    self.nudgeButton.set_icon_widget(imgNudge)
         else:
                 size = gtk.ICON_SIZE_LARGE_TOOLBAR
 
@@ -1564,15 +1686,23 @@ class ToolbarWidget(gtk.Toolbar):
         conversation = self.parentUI.parentConversation
         if conversation.switchboard.status == 'error' \
          or not self.controller or not self.controller.msn:
-            self.nudgeButton.set_sensitive(False)
-            self.inviteButton.set_sensitive(False)
-            self.sendfileButton.set_sensitive(False)
-            self.smilieButton.set_sensitive(False)
+            if self.nudgeButton:
+                self.nudgeButton.set_sensitive(False)
+            if self.inviteButton:
+                self.inviteButton.set_sensitive(False)
+            if self.sendfileButton:
+                self.sendfileButton.set_sensitive(False)
+            if self.smilieButton:
+                self.smilieButton.set_sensitive(False)
         else:
-            self.nudgeButton.set_sensitive(True)
-            self.inviteButton.set_sensitive(True)
-            self.sendfileButton.set_sensitive(True)
-            self.smilieButton.set_sensitive(True)
+            if self.nudgeButton:
+                self.nudgeButton.set_sensitive(True)
+            if self.inviteButton:
+                self.inviteButton.set_sensitive(True)
+            if self.sendfileButton:
+                self.sendfileButton.set_sensitive(True)
+            if self.smilieButton:
+                self.smilieButton.set_sensitive(True)
 
 class InviteWindow(gtk.Dialog):
     '''This class represent a list where the user can pick wich users
@@ -1672,3 +1802,4 @@ class InviteWindow(gtk.Dialog):
 
         self.hide()
 
+
