@@ -20,13 +20,12 @@ import gtk
 import pango
 import os
 import gobject
-
+import paths
 import abstract.stock
 import dialog
 # TODO: write p2p for ink, then you can reenable this.
 #import InkDraw
 import ConversationUI
-import emesenelib.common  # -.-"
 
 class ConversationWindow(gtk.Window):
     '''This class is the conversation window, it is just the frame
@@ -55,12 +54,6 @@ class ConversationWindow(gtk.Window):
         accelGroup = gtk.AccelGroup()
         self.add_accel_group(accelGroup)
         self.accelGroup = accelGroup
-        accelGroup.connect_group(gtk.keysyms.Page_Down, \
-                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED, \
-                                  self.on_key_cycle_tabs)
-        accelGroup.connect_group(gtk.keysyms.Page_Up, \
-                                  gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED, \
-                                  self.on_key_cycle_tabs)
         accelGroup.connect_group(gtk.keysyms.W, \
                                   gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED, \
                                   self.on_key_close_tab)
@@ -127,18 +120,10 @@ class ConversationWindow(gtk.Window):
         self.add(self.vbox)
 
         self.conversation.ui.hideUserList()
-        
-        # i use this for closing conversation with a middle click release
-        # the widget must be the same in which we generated the PRESS event
-        # and it must followed by a RELEASE event in the same widget
-        self.lastWidget = None
-        self.lastEventType = None 
-        
+                
     def on_key_press(self, widget, event):
-        if (event.state & gtk.gdk.CONTROL_MASK) and \
-           (event.keyval == gtk.keysyms.Tab or \
-           event.keyval == gtk.keysyms.ISO_Left_Tab):
-            if event.state & gtk.gdk.SHIFT_MASK:
+        if (event.state & gtk.gdk.CONTROL_MASK) and event.keyval in [ gtk.keysyms.Tab, gtk.keysyms.ISO_Left_Tab, gtk.keysyms.Page_Down, gtk.keysyms.Page_Up]:
+	    if event.state & gtk.gdk.SHIFT_MASK or event.keyval == gtk.keysyms.Page_Up:
                 self.cycleTabs(-1)
             else:
                 self.cycleTabs(1)
@@ -163,18 +148,6 @@ class ConversationWindow(gtk.Window):
         if new < pages:
             self.showTab(new)
 
-    def on_key_cycle_tabs(self, accelGroup, window, keyval, modifier):
-        '''Catches events like Ctrl+AvPag and consequently changes current
-        tab'''
-
-        if not modifier == gtk.gdk.CONTROL_MASK:
-            return
-
-        if keyval == gtk.keysyms.Page_Down:
-            self.cycleTabs(1)
-        elif keyval == gtk.keysyms.Page_Up:
-            self.cycleTabs(-1)
-
     def on_menubar_change(self, _config, value, oldValue):
         '''handler for showMenubar config change'''
         if value == '1':
@@ -279,9 +252,9 @@ class ConversationWindow(gtk.Window):
 
     def update_title(self):
         '''change window title to parsed title of current conversation'''
-        self.set_title(emesenelib.common.unescape(
-            self.controller.unifiedParser.getParser(
-            self.conversation.getTitle()).get()))
+        self.set_title(\
+            self.controller.unifiedParser.getParser(\
+            self.conversation.getTitle()).get(escaped=False))
 
     def openTab(self, conversation):
         '''open a new tab, that represent a new conversation'''
@@ -368,7 +341,9 @@ class ConversationWindow(gtk.Window):
         conversation.setStatus('closed')
         conversation.setClosed(True)
         conversation.ui.close()
-        self.conversations.remove(conversation)
+        
+        if conversation in self.conversations:
+            self.conversations.remove(conversation)
 
         self.controller.conversationManager.emit('close-conversation-ui', \
             conversation, self)
@@ -387,10 +362,7 @@ class ConversationWindow(gtk.Window):
     def tabs_event(self, _widget, event, ui):
         '''closes a tab on middleclick press+release'''
         if event.type == gtk.gdk.BUTTON_RELEASE and event.button == 2:
-            if self.lastWidget == _widget and self.lastEventType == gtk.gdk.BUTTON_PRESS:
-                self.closeTab(ui.parentConversation)
-        self.lastWidget = _widget
-        self.lastEventType = event.type
+            self.closeTab(ui.parentConversation)
         
     def clearOutputText(self, *args):
         self.conversation.textBuffer.set_text('')
@@ -477,9 +449,6 @@ class ConversationWindow(gtk.Window):
         '''return True if the window has been hided'''
         return self.closed
 
-    def scrollToBottom(self, tab_num = None):
-        self.conversation.ui.scrollToBottom()
-
     def addChildAtAnchor(self, child, anchor, tab_num = None):
         '''add a child to an anchor in the current output if tab_num is None, otherwise add it in the tab'''
         # TODO: this method should be in conversation(ui)
@@ -589,7 +558,7 @@ class ConversationWindow(gtk.Window):
         dialog = gtk.FileChooserDialog(_('Send file'),
             buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                      gtk.STOCK_OPEN, gtk.RESPONSE_OK))
-        dialog.set_current_folder(os.path.expanduser('~'))
+        dialog.set_current_folder(paths.HOME_DIR)
 
         response = dialog.run()
 
