@@ -20,10 +20,12 @@ import os
 import gtk
 import gobject
 import base64 # yes base64, go out and look how gaim does it :P
+import shutil
 
 import paths
 import Widgets
 import dialog
+import stock
 import emesenelib.common
 
 class Login(gtk.VBox):
@@ -105,18 +107,21 @@ class Login(gtk.VBox):
         self.statusList = []
         j = 0
         for i in self.controller.status_ordered[ 1 ]:
-            if i != 'offline':
+            if i != 'offline' and i not in self.statusList:
                 self.statusListStore\
                         .append([ self.controller.theme.statusToPixbuf(
                                emesenelib.common.status_table[i]).scale_simple(20,20,gtk.gdk.INTERP_BILINEAR), i,
-                               _(self.controller.status_ordered[2][ j]) ])
+                               _(self.controller.status_ordered[2][j]) ])
                 self.statusList.append(i)
-                j += 1
+            j += 1
 
         self.tStatus.set_active(0)
 
         pixbuf = self.controller.theme.getImage('login', False)
-        self.loginImage = Widgets.avatarHolder()
+        if (os.name == 'nt'):
+            self.loginImage = gtk.Image()
+        else:
+            self.loginImage = Widgets.avatarHolder()
         self.loginImage.set_from_pixbuf(pixbuf)
         if not self.controller.config.glob['dontShowAvatarInLoginWindow']:
             self.pack_start(self.loginImage , True , False)
@@ -151,10 +156,10 @@ class Login(gtk.VBox):
         fieldsAlig.add(self.fieldsBox)
         self.pack_start(fieldsAlig, True, False)
 
-        buttonBox = gtk.HButtonBox()
-
         self.lReconnectCounter = None
 
+        buttonBox = gtk.HButtonBox()
+
         if interface == 'login':
             self.bLogin = gtk.Button(_('_Login'), gtk.STOCK_CONNECT)
             self.bLogin.connect('clicked' , self.bLogin_clicked)
@@ -190,16 +195,38 @@ class Login(gtk.VBox):
             rememberBox = gtk.HBox(spacing=4)
             rememberBox.pack_start(self.cRemember , False , False)
             rememberBox.pack_start(self.forgetMe , False , False)
-
+                
             self.checkBox.pack_start(rememberBox, False, False)
-            self.checkBox.pack_start(self.cRememberPass , False , False)
-            self.checkBox.pack_start(self.cAutoLogin , False , False)
+            self.checkBox.pack_start(self.cRememberPass, False, False)
+            self.checkBox.pack_start(self.cAutoLogin, False, False)
 
+            try:
+                import locale
+                link = "http://status.messenger.msn.com/Status.aspx?mkt="
+                link += locale.getlocale()[0].replace('_','-')
+                serverStatus = gtk.LinkButton(link,_('Service Status'))
+                self.checkBox.pack_start(serverStatus, False, False)
+            except:
+                # some people have really weird python installs
+                pass
+                            
             checkAlig = gtk.Alignment(0.5, 0.5)
             checkAlig.add(self.checkBox)
 
             self.pack_start(checkAlig , True , False)
 
+            serverBox = gtk.VBox(spacing=40)
+            serverLBox = gtk.HBox(spacing=6)
+
+            serverBox.pack_start(serverLBox , False , False)
+
+            checkAlig1 = gtk.Alignment(0.5, 0.5)
+            checkAlig1.add(serverBox)
+
+            self.pack_start(buttonBox, True, False)
+        
+            self.pack_start(checkAlig1, True, False)
+
         elif interface == 'reconnect':
             self.fieldsBox.set_sensitive(False)
 
@@ -210,10 +237,14 @@ class Login(gtk.VBox):
 
             self.bCancelReconnect = gtk.Button(_('Cancel'), gtk.STOCK_CANCEL)
             self.bCancelReconnect.connect('clicked', self.onCancelReconnect)
+            self.bReconnectNow = gtk.Button(_('Reconnect now'), gtk.STOCK_CONNECT)
+            self.bReconnectNow.connect('clicked' , self.onReconnectNow)
 
             self.pack_start(self.lConnectionError, True, False)
             self.pack_start(self.lReconnectCounter, True, False)
+            buttonBox.pack_start(self.bReconnectNow, True, False)
             buttonBox.pack_start(self.bCancelReconnect, False, False)
+            self.pack_start(buttonBox, True, False)
         elif interface == 'loading':
             self.fieldsBox.set_sensitive(False)
 
@@ -225,6 +256,7 @@ class Login(gtk.VBox):
             buttonBox.pack_start(cancelButton, False, False)
 
             self.pack_start(self.loading, False, False)
+            self.pack_start(buttonBox, True, False)
             # XXX: progress stuff maybe?
 
         # fill the user list
@@ -232,7 +264,6 @@ class Login(gtk.VBox):
         if self.users.userExists(self.controller.config.glob['lastLoggedAccount']):
                 self.tUser.get_children()[0].set_text(self.controller.config.glob['lastLoggedAccount'])
 
-        self.pack_start(buttonBox, True, False)
         self.show_all()
         self.tUser.grab_focus()
 
@@ -241,32 +272,43 @@ class Login(gtk.VBox):
         self.tUser.set_active(0)
         self.tPass.set_text(password)
 
-        statusOrdered = self.controller.status_ordered[1]
-        if status in statusOrdered:
-            self.tStatus.set_active(statusOrdered.index(status))
+        i = 0
+        for item in self.statusListStore:
+            if item[1] == status: break
+            i += 1
+        self.tStatus.set_active(i)
 
     def onCancelReconnect(self, *args):
         self.controller.cancelReconnect()
 
     def onCancelLogin(self,*args):
         self.controller.cancelLogin()
-
+        
+    def onReconnectNow(self,*args):
+        self.lReconnectCounter.set_text(_('Reconnecting...'))
+        self.login()
+        
     def refreshUserList(self):
         '''fill the user list to the completion and combo'''
 
         self.userListStore.clear()
-        for i in sort(self.users.getUsers()):
-            self.userListStore.append([ i , self.controller.theme.getImage('online') ])
+        for i in sorted(self.users.getUsers(), key=lambda x: x.lower()):
+            self.userListStore.append([ i , self.controller.theme.getImage('online').scale_simple(20,20,gtk.gdk.INTERP_BILINEAR) ])
 
     def on_cRemember_toggled(self , *args):
+        self.controller.config.glob['rememberMe'] = self.cRemember.get_active()
         if not self.cRemember.get_active():
             self.cRememberPass.set_active(False)
 
     def on_cRememberPass_toggled(self , *args):
         if self.cRememberPass.get_active():
+            self.controller.config.glob['rememberMyPassword'] = True
             self.cRemember.set_active(True)
+            self.cRemember.set_sensitive(False)
         else:
+            self.controller.config.glob['rememberMyPassword'] = False
             self.cAutoLogin.set_active(False)
+            self.cRemember.set_sensitive(True)
             # Reset password
             if self.users.userExists(self.getUser()):
                 if self.users.getPassword(self.getUser()) != '':
@@ -279,14 +321,15 @@ class Login(gtk.VBox):
         if self.cAutoLogin.get_active():
             self.controller.config.glob['autoLogin'] = True
             self.cRememberPass.set_active(True)
+            self.cRememberPass.set_sensitive(False)
         else:
             self.controller.config.glob['autoLogin'] = False
+            self.cRememberPass.set_sensitive(True)
 
     def setReconnectCounter(self, seconds):
         if self.lReconnectCounter:
             if seconds > 0:
-                # FIXME: use %s instead
-                self.lReconnectCounter.set_text(_('Reconnecting in ') + str(seconds) + _(' seconds'))
+                self.lReconnectCounter.set_text(_('Reconnecting in %s seconds') % str(seconds))
             else:
                 self.lReconnectCounter.set_text(_('Reconnecting...'))
 
@@ -295,7 +338,7 @@ class Login(gtk.VBox):
 
     def bLogin_clicked(self , *args):
         if self.getUser() == '' or self.getPass() == '' or self.getStatus() == '':
-            dialog.error(_("User or password empty"))
+            self.parent.parent.showNiceBar(_("User or password empty"), self.controller.niceBarWarningColor, gtk.STOCK_DIALOG_WARNING)
             return
 
         if self.currentInterface == 'login' and self.cRemember.get_active():
@@ -318,7 +361,7 @@ class Login(gtk.VBox):
         return self.tPass.get_text()
 
     def getStatus(self):
-        return self.statusListStore.get(self.tStatus.get_active_iter(), 1)[ 0 ]
+        return self.statusListStore.get(self.tStatus.get_active_iter(), 1)[0]
 
     def on_comboxEntry_changed(self, *args):
         self.getPreferences(self.getUser())
@@ -390,12 +433,24 @@ class Login(gtk.VBox):
 
     def onForgetMe(self, *args):
         '''This method is called when the user press the forget me event box'''
-        self.users.removeUser(self.getUser())
-        self.tUser.get_children()[0].set_text('')
-        self.tPass.set_text('')
-        self.forgetMe.set_child_visible(False)
-        self.refreshUserList()
-        self.users.save()
+        def _yes_no_cb(response):
+            '''callback from the confirmation dialog'''
+            if response == stock.YES:
+                try: # Delete user's folder
+                    user = self.getUser().replace('@', '_').replace('.', '_')
+                    shutil.rmtree(os.path.join(paths.CONFIG_DIR, user))
+                except: 
+                    pass
+
+                self.users.removeUser(self.getUser())
+                self.tUser.get_children()[0].set_text('')
+                self.tPass.set_text('')
+                self.forgetMe.set_child_visible(False)
+                self.refreshUserList()
+                self.users.save()
+
+        dialog.yes_no(
+            _('Are you sure you want to delete the account %s ?') % self.getUser() , _yes_no_cb)
 
     def on_comboxEntry_keyrelease(self, widget, event):
         if event.keyval == gtk.keysyms.Tab:
@@ -493,27 +548,12 @@ class UserManager(object):
 
     def load(self):
         '''load the content of the file'''
-
-        justCreated = False
-
         try:
-            usersList = open(self.path, 'r')
-        except:
-            usersList = open(self.path , 'w')
-            justCreated = True
-
-        if not justCreated:
-            for line in usersList.readlines():
+            usersListRead = open(self.path, 'r')
+            for line in usersListRead.readlines():
                 (user,password,status) = line.strip().split(':')
                 self.users[ user ] = (password, status)
-
-        usersList.close()
-
-def sort(list):
-    '''Sorts a list in alphabetical order
-    without regard of the capitalization'''
-
-    list = list[:]
-    list.sort(key=lambda x: str.lower(x))
-    return list
-
+            usersListRead.close()
+        except:
+            usersList = open(self.path , 'w')
+            usersList.close()
