@@ -20,6 +20,7 @@ import gtk
 import desktop
 import StatusMenu
 import PreferenceWindow
+import SmilieWindow
 
 import stock
 import dialog
@@ -39,18 +40,14 @@ class MainMenu(gtk.MenuBar):
         self.theme = self.controller.theme
 
         fileMenu = gtk.Menu()
-        fileMenuItem = self.newImageMenuItem(_('_File'))
+        fileMenuItem = self.newImageMenuItem(_('_Account'))
         fileMenuItem.set_submenu(fileMenu)
 
         # If we're in login window we don't need the View
         # or the Actions Menu
         if window_type == 'userlist':
-            viewMenu = gtk.Menu()
-            viewMenuItem = self.newImageMenuItem(_('_View'))
-            viewMenuItem.set_submenu(viewMenu)
-
             actionsMenu = gtk.Menu()
-            actionsMenuItem = self.newImageMenuItem(_('_Actions'))
+            actionsMenuItem = self.newImageMenuItem(_('_Contacts'))
             actionsMenuItem.connect('activate', self.on_actions_activate)
             actionsMenuItem.set_submenu(actionsMenu)
 
@@ -62,7 +59,7 @@ class MainMenu(gtk.MenuBar):
         helpMenuItem = self.newImageMenuItem(_('_Help'))
         helpMenuItem.set_submenu(helpMenu)
 
-        # ---------------------- FILE MENU --------------------------------
+        # ---------------------- ACCOUNT MENU --------------------------------
 
         # In login window only quit option is usefull
         if window_type == 'userlist':
@@ -72,22 +69,7 @@ class MainMenu(gtk.MenuBar):
             statusMenuItem.set_submenu(statusMenu)
             fileMenu.add(statusMenuItem)
 
-            fileMenu.add(gtk.SeparatorMenuItem())
-            exportMenu = gtk.Menu()
-            exportAsPlain = self.newImageMenuItem(_('Export as plain text'), \
-                                                    gtk.STOCK_FILE)
-            exportAsCtt = self.newImageMenuItem(_('Export as .Ctt'), \
-                                                    gtk.STOCK_DIALOG_AUTHENTICATION)
-            exportMenu.add(exportAsPlain)
-            exportMenu.add(exportAsCtt)
-            export = self.newImageMenuItem(_('E_xport contact list'), \
-                                                    gtk.STOCK_FLOPPY)
-            export.set_submenu(exportMenu)
-    
-            exportAsPlain.connect('activate', self.on_export_activate,'plain')
-            exportAsCtt.connect('activate', self.on_export_activate,'ctt')
             disconnect = self.newStockImageMenuItem(gtk.STOCK_DISCONNECT)
-            fileMenu.add(export)
             fileMenu.add(gtk.SeparatorMenuItem())
             fileMenu.add(disconnect)
         else:
@@ -105,80 +87,26 @@ class MainMenu(gtk.MenuBar):
         accelGroup.connect_group(ord('Q'), gtk.gdk.CONTROL_MASK, \
             gtk.ACCEL_LOCKED, self.on_quit_activate)
 
-        # -------------------- VIEW MENU ----------------------------------
+        # ------------------- CONTACTS MENU --------------------------------
 
-        # Action Menu is useless in login window
+        # Contacts Menu is useless in login window
         if window_type == 'userlist':
-            self.orderByGroup = gtk.RadioMenuItem(None, \
-                                                      _('Order by _group'))
-            self.orderByStatus = gtk.RadioMenuItem(self.orderByGroup, \
-                                                      _('Order by _status'))
-            if not self.config.user['orderByStatus']:
-                self.orderByGroup.set_active(True)
-            else:
-                self.orderByStatus.set_active(True)
-
-            viewMenu.add(self.orderByGroup)
-            viewMenu.add(self.orderByStatus)
-            viewMenu.add(gtk.SeparatorMenuItem())
-
-            # Menu items to switch the contacts within each group
-            self.orderGroupByEmail = gtk.RadioMenuItem(None, \
-                                                      _('Order group by e_mail'))
-            self.orderGroupByNick = gtk.RadioMenuItem(self.orderGroupByEmail, \
-                                                      _('Order group by n_ick'))
-
-            if self.config.user['sortNickGroupByContact']:
-                self.orderGroupByEmail.set_active(True)
-            else:
-                self.orderGroupByNick.set_active(True)
-
-            viewMenu.add(self.orderGroupByEmail)
-            viewMenu.add(self.orderGroupByNick)
-            viewMenu.add(gtk.SeparatorMenuItem())
-
-            self.showByNick = self.newCheckMenuItem(_('Show by _nick'), \
-                    self.config.user['showByNick'])
-            self.showOffline = self.newCheckMenuItem(_('Show _offline'), \
-                    self.config.user['showOffline'])
-            self.showEmptyGroups = self.newCheckMenuItem(
-             _('Show _empty groups'), self.config.user['showEmptyGroups'])
-            self.showCountContact = self.newCheckMenuItem(
-                _('Show _contact count'),
-                self.config.user['showCountContact'])
-
-            viewMenu.add(self.showByNick)
-            viewMenu.add(self.showOffline)
-            viewMenu.add(self.showEmptyGroups)
-            viewMenu.add(self.showCountContact)
-
-        # ------------------- ACTIONS MENU --------------------------------
-
-        # Action Menu is useless in login window
-        if window_type == 'userlist':
-            # Add user, group
-            addUserMenuItem = self.newImageMenuItem(_('_Add contact...'), \
+            # Add user, remove
+            addUserMenuItem = self.newImageMenuItem(_('_Add contact'), \
                                                      gtk.STOCK_ADD)
             actionsMenu.add(addUserMenuItem)
 
-            addGroupMenuItem = self.newImageMenuItem(_('Add _group...'),
-                gtk.STOCK_ADD)
-            actionsMenu.add(addGroupMenuItem)
-
-            actionsMenu.add(gtk.SeparatorMenuItem())
-
-            # Contacts action group: remove, block, unblock
             contactsActionGroup = gtk.ActionGroup('contacts')
             self.contactsActionGroup = contactsActionGroup
 
             setAliasAction = gtk.Action('setAlias',
                 _('_Set contact alias...'), None, gtk.STOCK_EDIT)
+            moveAction = gtk.Action('move', _('M_ove to group'), \
+                                     None, gtk.STOCK_REDO)
             blockAction = gtk.Action('block', _('_Block'), \
                                         None, gtk.STOCK_STOP)
             unblockAction = gtk.Action('unblock', _('_Unblock'), \
                                         None, gtk.STOCK_APPLY)
-            moveAction = gtk.Action('move', _('M_ove to group'), \
-                                     None, gtk.STOCK_REDO)
             deleteAction = gtk.Action('delete', _('_Remove contact'), \
                                         None, gtk.STOCK_DELETE)
 
@@ -193,46 +121,135 @@ class MainMenu(gtk.MenuBar):
             actionsMenu.add(unblockAction.create_menu_item())
             contactsActionGroup.add_action(moveAction)
             self.moveMenuItem = moveAction.create_menu_item()
+            self.moveToGroupMenuSelected(self.moveMenuItem)
             self.moveMenuItem.connect('activate', self.moveToGroupMenuSelected)
             actionsMenu.add(self.moveMenuItem)
             contactsActionGroup.add_action(deleteAction)
             actionsMenu.add(deleteAction.create_menu_item())
-            
+
             actionsMenu.add(gtk.SeparatorMenuItem())
-            # Groups action group: remove, rename
+
+            # Groups action group: Add, remove, rename
+            addGroupMenuItem = self.newImageMenuItem(_('Add _group'),
+                gtk.STOCK_ADD)
+            actionsMenu.add(addGroupMenuItem)
+
             groupsActionGroup = gtk.ActionGroup('groups')
             self.groupsActionGroup = groupsActionGroup
 
+            renameAction = gtk.Action('rename', _('Re_name group'), \
+                                        None, gtk.STOCK_EDIT)
             deleteGAction = gtk.Action('remove', _('Re_move group'), \
                                         None, gtk.STOCK_DELETE)
-            renameAction = gtk.Action('rename', _('Re_name group...'), \
-                                        None, gtk.STOCK_EDIT)
 
             groupsActionGroup.add_action(renameAction)
             actionsMenu.add(renameAction.create_menu_item())
             groupsActionGroup.add_action(deleteGAction)
             actionsMenu.add(deleteGAction.create_menu_item())
 
+            actionsMenu.add(gtk.SeparatorMenuItem())
+
+            # Show Contacts
+            FilterContactsMenuItem = self.newImageMenuItem(_("Show..."))
+            FilterContactsMenu = gtk.Menu()
+            FilterContactsMenuItem.set_submenu(FilterContactsMenu)
+            FilterContactsMenuItem.show_all()
+            actionsMenu.add(FilterContactsMenuItem)
+
+            self.showByNick = self.newCheckMenuItem(_('Contacts by _nick'), \
+                    self.config.user['showByNick'])
+            self.showOffline = self.newCheckMenuItem(_('Contacts _offline'), \
+                    self.config.user['showOffline'])
+            self.showEmptyGroups = self.newCheckMenuItem(
+             _('_Empty groups'), self.config.user['showEmptyGroups'])
+            self.showCountContact = self.newCheckMenuItem(
+                _('_Contact count'),
+                self.config.user['showCountContact'])
+
+            FilterContactsMenu.add(self.showByNick)
+            FilterContactsMenu.add(self.showOffline)
+            FilterContactsMenu.add(self.showEmptyGroups)
+            FilterContactsMenu.add(self.showCountContact)
+
+            # Order Contacts
+            OrderContactsMenuItem = self.newImageMenuItem(_("Order contacts by..."))
+            OrderContactsMenu = gtk.Menu()
+            OrderContactsMenuItem.set_submenu(OrderContactsMenu)
+            OrderContactsMenuItem.show_all()
+            actionsMenu.add(OrderContactsMenuItem)
+
+            self.orderByGroup = gtk.RadioMenuItem(None, \
+                                                      _('_Group-ordered'))
+            self.orderByStatus = gtk.RadioMenuItem(self.orderByGroup, \
+                                                      _('_Status-ordered'))
+            if not self.config.user['orderByStatus']:
+                self.orderByGroup.set_active(True)
+            else:
+                self.orderByStatus.set_active(True)
+
+            OrderContactsMenu.add(self.orderByGroup)
+            OrderContactsMenu.add(self.orderByStatus)
+
+            # Menu items to switch the contacts within each group
+            SortContactsMenuItem = self.newImageMenuItem(_("Sort contacts by..."))
+            SortContactsMenu = gtk.Menu()
+            SortContactsMenuItem.set_submenu(SortContactsMenu)
+            SortContactsMenuItem.show_all()
+            actionsMenu.add(SortContactsMenuItem)
+
+            self.orderGroupByEmail = gtk.RadioMenuItem(None, \
+                                                      _('E_mail'))
+            self.orderGroupByNick = gtk.RadioMenuItem(self.orderGroupByEmail, \
+                                                      _('N_ick'))
+
+            if self.config.user['sortNickGroupByContact']:
+                self.orderGroupByEmail.set_active(True)
+            else:
+                self.orderGroupByNick.set_active(True)
+
+            SortContactsMenu.add(self.orderGroupByEmail)
+            SortContactsMenu.add(self.orderGroupByNick)
+
+            actionsMenu.add(gtk.SeparatorMenuItem())
+
+            # Export contact list
+            exportMenu = gtk.Menu()
+            exportAsPlain = self.newImageMenuItem(_('As plain text'), \
+                                                    gtk.STOCK_FILE)
+            exportAsCtt = self.newImageMenuItem(_('As .Ctt'), \
+                                                    gtk.STOCK_DIALOG_AUTHENTICATION)
+            exportMenu.add(exportAsPlain)
+            exportMenu.add(exportAsCtt)
+            export = self.newImageMenuItem(_('Save contact list...'), \
+                                                    gtk.STOCK_FLOPPY)
+            export.set_submenu(exportMenu)
+    
+            exportAsPlain.connect('activate', self.on_export_activate,'plain')
+            exportAsCtt.connect('activate', self.on_export_activate,'ctt')
+            actionsMenu.add(export)
+
+
         # ------------------------ OPTIONS MENU ---------------------------
 
         if window_type == 'userlist':
-            changeNickMenuItem = self.newImageMenuItem(\
-                _('_Change nick...'), gtk.STOCK_EDIT)
-            changeAvatarMenuItem = self.newImageMenuItem(\
-                _('Change _display picture...'), gtk.STOCK_EDIT)
-            optionsMenu.add(changeNickMenuItem)
-            optionsMenu.add(changeAvatarMenuItem)
+            #profileMenuItem to replace nick and avatar menu items
+            changeProfileMenuItem = self.newImageMenuItem(\
+                _('Change profile...'), gtk.STOCK_EDIT)
+            optionsMenu.add(changeProfileMenuItem)
 
             optionsMenu.add(gtk.SeparatorMenuItem())
 
-            setAutoReplyMenuItem = self.newImageMenuItem(\
-                _('Edit a_utoreply...'), gtk.STOCK_EDIT)
+            autoReplyMenuItem = self.newImageMenuItem(\
+                _('A_utoreply'), gtk.STOCK_EDIT)
 
-            self.activateAutoReply = self.newCheckMenuItem(\
-                _('Activate au_toreply'), self.config.user['autoReply'])
+            optionsMenu.add(autoReplyMenuItem)
 
-            optionsMenu.add(self.activateAutoReply)
-            optionsMenu.add(setAutoReplyMenuItem)
+            optionsMenu.add(gtk.SeparatorMenuItem())
+
+            # Add Emoticon's
+            addEmoticonMenuItem = self.newImageMenuItem(_('_Add an emoticon...'), \
+                                                     gtk.STOCK_ADD)
+            optionsMenu.add(addEmoticonMenuItem)
 
             optionsMenu.add(gtk.SeparatorMenuItem())
 
@@ -266,7 +283,6 @@ class MainMenu(gtk.MenuBar):
 
         # No Actions Menu in login window
         if window_type == 'userlist':
-            self.add(viewMenuItem)
             self.add(actionsMenuItem)
 
         self.add(optionsMenuItem)
@@ -301,21 +317,18 @@ class MainMenu(gtk.MenuBar):
             self.showCountContact.connect('activate',
                 self.on_show_count_contact_activate)
             addUserMenuItem.connect('activate', self.on_add_user_activate)
+            addEmoticonMenuItem.connect('activate', self.on_emoticon_activate)
             setAliasAction.connect('activate', self.on_rename_user_activate)
             deleteAction.connect('activate', self.on_delete_user_activate)
-            blockAction.connect('activate', self.on_block_user_activate)
-            unblockAction.connect('activate', self.on_unblock_user_activate)
             addGroupMenuItem.connect('activate', self.on_add_group_activate)
             deleteGAction.connect('activate', self.on_delete_group_activate)
+            blockAction.connect('activate', self.on_block_user_activate)
+            unblockAction.connect('activate', self.on_unblock_user_activate)
             renameAction.connect('activate', self.on_rename_group_activate)
-            setAutoReplyMenuItem.connect('activate',
+            autoReplyMenuItem.connect('activate',
                 self.on_set_auto_reply_activate)
-            self.activateAutoReply.connect('activate',
-                self.on_auto_reply_activate)
-            changeNickMenuItem.connect('activate',
-                self.on_change_nick_activate)
-            changeAvatarMenuItem.connect('activate',
-                self.on_change_avatar_activate)
+            changeProfileMenuItem.connect('activate',
+                self.on_change_profile_activate)
             pluginMenuItem.connect('activate', self.on_plugin_activate)
         else:
             getliveMenuItem.connect('activate', self.on_get_live_activate)
@@ -327,11 +340,18 @@ class MainMenu(gtk.MenuBar):
         '''build the submenu, please'''
         moveMenu = gtk.Menu()
 
-        for i in self.controller.msn.getGroupNames():
-            i = i.replace('_', '__') # don't use _ as mnemonic
-            menuItem = gtk.MenuItem (i)
-            moveMenu.add(menuItem)
-            menuItem.connect('activate', self.on_move_to_activate, i)
+        groups = self.controller.msn.getGroupNames()
+        if groups == []:
+            addGroupMenuItem = self.newImageMenuItem(_('Add _group'),
+                gtk.STOCK_ADD)
+            moveMenu.add(addGroupMenuItem)
+            addGroupMenuItem.connect('activate', self.on_add_group_activate)
+        else:
+            for i in groups:
+                i = i.replace('_', '__') # don't use _ as mnemonic
+                menuItem = gtk.MenuItem (i)
+                moveMenu.add(menuItem)
+                menuItem.connect('activate', self.on_move_to_activate, i)
            
         self.moveMenuItem.set_submenu(moveMenu)
         moveMenu.show_all()
@@ -369,7 +389,7 @@ class MainMenu(gtk.MenuBar):
     # -------------------------- CALLBACKS -------------------------------
 
     def on_export_activate(self, dialog,format):
-        chooser = gtk.FileChooserDialog(title='Save conact list as...',action=gtk.FILE_CHOOSER_ACTION_SAVE,
+        chooser = gtk.FileChooserDialog(title=_('Save contact list as...'),action=gtk.FILE_CHOOSER_ACTION_SAVE,
             buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))
         filter = gtk.FileFilter()
         if format=='ctt':
@@ -379,7 +399,7 @@ class MainMenu(gtk.MenuBar):
         else:
             filter.set_name('All files')
             filter.add_pattern('*')
-            chooser.set_current_name('myContacts')
+            chooser.set_current_name(_('myContacts'))
         chooser.add_filter(filter)
         chooser.set_current_folder(os.environ['HOME'])
         response = chooser.run()
@@ -420,8 +440,8 @@ class MainMenu(gtk.MenuBar):
         data = self.controller.getMenuData()
         typeSelected = data[0]
 
-        self.contactsActionGroup.set_sensitive(typeSelected == 'user')
-        self.groupsActionGroup.set_sensitive\
+        self.contactsActionGroup.set_visible(typeSelected == 'user')
+        self.groupsActionGroup.set_visible\
                     (typeSelected == 'group' and data[2] != 'nogroup')
 
         # set selected data class-available
@@ -430,9 +450,9 @@ class MainMenu(gtk.MenuBar):
             self.userName = data[1]
             self.userGroup = data[2]
             # block/unblock
-            blocked = self.controller.contacts.get_blocked(data[1])
-            self.blockAction.set_sensitive(not blocked)
-            self.unblockAction.set_sensitive(blocked)
+            blocked = data[4]
+            self.blockAction.set_visible(not blocked)
+            self.unblockAction.set_visible(blocked)
         if typeSelected == 'group':
             self.groupName = data[1]
 
@@ -519,21 +539,26 @@ class MainMenu(gtk.MenuBar):
             self.showCountContact.get_active()
         self.controller.refreshUserList()
 
+    def on_emoticon_activate(self, *args):
+        smilieWindow = SmilieWindow.SmilieWindow(self.controller, \
+                                                None, None)
+        smilieWindow.addClicked(None, self.controller)
+
     def on_add_user_activate(self, *args):
         self.controller.addUserDialog()
 
     def on_delete_user_activate(self, *args):
         self.controller.contacts.remove(self.userName)
 
+    def on_add_group_activate(self, *args):
+        self.controller.groups.add_dialog()
+
     def on_block_user_activate(self, *args):
         self.controller.contacts.block(self.userName)
 
     def on_unblock_user_activate(self, *args):
         self.controller.contacts.unblock(self.userName)
 
-    def on_add_group_activate(self, *args):
-        self.controller.groups.add_dialog()
-
     def on_delete_group_activate(self, *args):
         self.controller.groups.remove(self.groupName)
 
@@ -546,29 +571,63 @@ class MainMenu(gtk.MenuBar):
     def on_change_nick_activate(self, *args):
         self.controller.contacts.set_nick_dialog()
 
+    def on_change_profile_activate(self, *args):
+        self.controller.change_profile_dialog()
+
     def on_set_auto_reply_activate(self, *args):
         def response_cb(response, message=''):
             '''callback for the set autoreply dialog'''
-            if response == stock.ACCEPT:
-                if message == '':
+            if response == gtk.RESPONSE_ACCEPT:
+                if self.checkbox.get_active() and message == '':
                     dialog.error(_("Empty autoreply"))
                 else:
-                    self.controller.autoReplyMessage = message
+                    self.config.user['autoReply'] = self.checkbox.get_active()
                     self.config.user['autoReplyMessage'] = message
 
-        window = dialog.entry_window(_("Autoreply message:"),
-            self.config.user['autoReplyMessage'], response_cb,
-            _("Change autoreply"))
-        window.set_resizable(False)
-        window.show()
+        replyDialog = gtk.Dialog( _("Autoreply") , None,
+                          gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+                          (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
+                           gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
 
-    def on_auto_reply_activate(self, *args):
-        self.config.user['autoReply'] = self.activateAutoReply.get_active()
+        replyDialog.set_border_width(2)
+
+        self.checkbox = gtk.CheckButton(_('Activate au_toreply'))
+        self.checkbox.set_active(self.config.user['autoReply'])
+
+        self.entry = gtk.Entry()
+        self.entry.set_text(self.config.user['autoReplyMessage'])
+        self.entry.set_sensitive(self.checkbox.get_active())
+        self.entry.set_size_request(300,-1)
+        label = gtk.Label()
+        label.set_text(_("Autoreply message:"))
+        aligLabel = gtk.Alignment(xalign=0.0)
+        aligLabel.add(label)
+        aligLabel.set_padding(0,0,15,0)
+        aligEntry = gtk.Alignment()
+        aligEntry.set_padding(0, 0, 15, 15)
+        aligEntry.add(self.entry)
+
+        replyDialog.vbox.set_spacing(4)
+        replyDialog.vbox.pack_start(self.checkbox, False, False)
+        replyDialog.vbox.pack_start(aligLabel, False, False)
+        replyDialog.vbox.pack_start(aligEntry, False, False)
+        replyDialog.vbox.show_all()
+
+        self.checkbox.connect('toggled', self.on_auto_reply_toggled)
+
+        response = replyDialog.run()
+        replyDialog.destroy()
+        response_cb(response, self.entry.get_text())
+
+    def on_auto_reply_toggled(self, check):
+        self.entry.set_sensitive(check.get_active())
 
     def on_plugin_activate(self, *args):
-        self.controller.pluginDialog()
+        if not self.controller.preference_open:
+            PreferenceWindow.PreferenceWindow(self.controller,
+                self.config, self.controller.mainWindow, 6).show() #6 is the index of the plugin page
+            self.controller.preference_open = True
 
     def on_get_live_activate(self, *args):
         link = 'https://accountservices.passport.net/reg.srf?sl=1'
         desktop.open(link)
-
