@@ -79,6 +79,7 @@ class MainWindow(gtk.Window):
                                           theme.getImage('icon48'),
                                           theme.getImage('icon96'))
 
+        self.windowVBox = None
         self.vbox = None
         self.login = None
         self.userList = None
@@ -177,7 +178,7 @@ class MainWindow(gtk.Window):
             user = passwd = status = ''
 
         if self.get_child():
-            self.remove(self.vbox)
+            self.remove(self.windowVBox)
 
         if self.userList:
             self.userList.tooltips.hideTooltip()
@@ -195,6 +196,8 @@ class MainWindow(gtk.Window):
         #widgets
 
         self.vbox = gtk.VBox(spacing=2)
+        self.vbox.set_border_width(3)
+        self.windowVBox = gtk.VBox()
         self.scroll = gtk.ScrolledWindow()
         self.scroll.set_policy(gtk.POLICY_NEVER , gtk.POLICY_AUTOMATIC)
         self.scroll.set_shadow_type(gtk.SHADOW_IN)
@@ -202,15 +205,14 @@ class MainWindow(gtk.Window):
                                        guiType, self.accelGroup)
 
         if guiType == 'login':
-            self.vbox.pack_start(self.menu, False, False)
+            self.initEventBox()
+            self.vbox.pack_start(self.eventBox, False, False, 0)
             self.login = Login.Login(self.controller, 'login')
-            if self.disconectionMessage != None:
-                self.vbox.pack_start(self.getStatusBar(), False, False, 0)
-                self.disconectionMessage = None
-            self.vbox.pack_start(self.login)
+            self.showNiceBar(self.disconectionMessage)
+            self.vbox.pack_end(self.login)
+
         elif guiType == 'userlist':
             self.login = None
-            self.vbox.pack_start(self.menu, False, False)
             self.userList = UserList.UserList(self.controller, \
                 self.controller.theme, self.controller.config)
             self.itemSelectedId = self.userList.connect('item-selected',
@@ -218,47 +220,68 @@ class MainWindow(gtk.Window):
 
             self.userPanel = UserPanel.UserPanel(self.controller)
             self.vbox.pack_start(self.userPanel, False, False)
+            self.statusCombo = StatusCombo(self.controller)
+            self.statusVBoxTop = gtk.VBox()
+            self.statusComboBottom = StatusCombo(self.controller)
+            self.statusVBoxBottom = gtk.VBox()
             self.filterEntry = FilterEntry.FilterEntry(
                 self.userList.setFilterText)
-            self.vbox.pack_start(self.filterEntry, False, False)
             self.scroll.add(self.userList)
             vbox2 = gtk.VBox()
             vbox2.pack_start(self.scroll)
-            self.statusCombo = StatusCombo(self.controller)
-            vbox2.pack_start(self.statusCombo, False, False)
-            vbox2.set_border_width(2)
-            self.vbox.pack_start(vbox2)
-            self.filterEntry.connect('filter-entry-lost-focus', self.lost_focus)
 
+            self.vbox.pack_start(self.statusVBoxTop, False, False)
+            self.vbox.pack_start(self.filterEntry, False, False)
+            self.vbox.pack_start(vbox2)
+            self.vbox.pack_start(self.statusVBoxBottom, False, False)
+
+            if self.config.user['statusComboOnTop']:
+                self.statusVBoxTop.pack_start(self.statusCombo, False, False)
+                self.statusVBoxTop.show_all()
+            else:
+                self.statusVBoxBottom.pack_start(self.statusCombo, False, False)
+                self.statusVBoxBottom.show_all()
+
+            self.filterEntry.connect('filter-entry-lost-focus', self.lost_focus)
             vbox2.show_all()
             self.controller.connect('preferences-changed',
                 self.updateConfig)
 
         elif guiType == 'loading':
             self.menu.set_sensitive(False)
-
             self.login = Login.Login(self.controller, 'loading')
             self.login.setFieldValues(user, passwd, status)
-            self.vbox.pack_start(self.menu, False, False)
             self.vbox.pack_start(self.login)
-            self.menu.show_all()
 
         elif guiType == 'reconnect':
             self.menu.set_sensitive(False)
             self.login = Login.Login(self.controller, 'reconnect')
-            self.vbox.pack_start(self.menu, False, False)
             self.vbox.pack_start(self.login)
-            self.menu.show_all()
 
+        self.windowVBox.pack_start(self.menu, False, False)
+        self.windowVBox.pack_start(self.vbox, True, True)
         self.menu.show_all()
-        self.add(self.vbox)
+        self.add(self.windowVBox)
         self.vbox.show()
+        self.windowVBox.show()
         self.update(self.controller)
 
         self.connect('delete-event' , self.hideOrClose)
         self.emit('gui-build-done', guiType)
         self.connect('key-press-event', self.on_key_press)
 
+
+    def toggle_status_box(self, combo):      
+        self.statusCombo.get_parent().remove(self.statusCombo)
+        if combo.get_active():
+            self.statusVBoxTop.pack_start(self.statusCombo, False, False)
+            self.statusVBoxTop.show_all()
+            self.filterEntry.queue_draw()
+        else:
+            self.statusVBoxBottom.pack_start(self.statusCombo, False, False)
+            self.statusVBoxBottom.show_all()
+            self.filterEntry.queue_draw()
+
     def lost_focus(self, widget):
         if self.filterEntry.entry.get_text() =='' and not self.config.user['showSearchEntry']:
             self.filterEntry.hide()
@@ -270,26 +293,31 @@ class MainWindow(gtk.Window):
         else:
             from gtk.gdk import CONTROL_MASK, MOD1_MASK
             if gtk.keysyms.Escape == event.keyval:
-                if self.filterEntry.entry.get_text() =='' and not self.config.user['showSearchEntry'] and self.filterEntry.entry.is_focus():
+                if self.filterEntry.entry.get_text() == '' and not \
+                   self.config.user['showSearchEntry'] and self.filterEntry.entry.is_focus():
                     self.filterEntry.hide()
                     return True
-                elif self.filterEntry.entry.get_text() !='':
+                elif self.filterEntry.entry.get_text() != '':
                     self.filterEntry.entry.set_text('')
                     return True
-                elif self.filterEntry.entry.get_text() =='':
+                elif self.filterEntry.entry.get_text() == '':
+                    if self.userPanel.isEditing():
+                        self.userPanel.stopEditing()
+                        return True
                     self.hideOrClose()
                     return True
-            elif  not self.userPanel.tNick.is_focus() and not self.userPanel.tPersonalMessage.is_focus(): 
+            elif not self.userPanel.tNick.is_focus() and not self.userPanel.tPersonalMessage.is_focus(): 
                 if not self.filterEntry.entry.is_focus() : 
                     if gtk.gdk.keyval_name(event.keyval)  in self.acceptedCharacters: 
                         if event.state & CONTROL_MASK or event.state & MOD1_MASK:
                             return False
                         else:
-                            if self.filterEntry.entry.get_text() =='' and not self.config.user['showSearchEntry']:
+                            if self.filterEntry.entry.get_text() == '' and not \
+                               self.config.user['showSearchEntry']:
                                 self.filterEntry.show()
                             self.filterEntry.entry.set_text(self.filterEntry.entry.get_text() + gtk.gdk.keyval_name(event.keyval))
                             self.filterEntry.entry.grab_focus()
-                            self.filterEntry.entry.set_position(self.filterEntry.entry.get_text_length())
+                            self.filterEntry.entry.set_position(len(self.filterEntry.entry.get_text()))
                             return True
 
     def updateConfig(self, *args):
@@ -360,21 +388,33 @@ class MainWindow(gtk.Window):
             else:
                 self.userList.expand_row(path, False)
 
-    def getStatusBar(self):
-        eventBox = gtk.EventBox()
-        box = gtk.HBox(False, 0)
-        eventBox.set_size_request(0, 30)
-        eventBox.add(box)
-        eventBox.modify_bg(gtk.STATE_NORMAL, self.controller.tooltipColor)
-        label = gtk.Label(self.disconectionMessage)
-        label.set_ellipsize(pango.ELLIPSIZE_END)
-        image = gtk.Image()
-        image.set_from_stock (gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        box.pack_start(image, False, False, 5)
-        box.pack_start(label, True, True, 5)
-        eventBox.show_all()
-        return eventBox
+    def initEventBox(self):
+        self.eventBox = gtk.EventBox()
+        self.box = gtk.HBox(False, 0)
+        self.eventBox.add(self.box)
+        self.label = gtk.Label()
+        self.label.set_line_wrap(True)
+        self.image = gtk.Image()
+        self.image.set_from_stock(gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_LARGE_TOOLBAR)
+        self.box.pack_start(self.image, False, False, 5)
+        self.box.pack_start(self.label, True, True, 5)
+        self.eventBox.connect("button-press-event", self.onClickNiceBar)
 
+    #Info bar by default
+    def showNiceBar(self,message,color=None,image=gtk.STOCK_DIALOG_INFO):
+        if message != None:
+            if color == None:
+                color = self.controller.tooltipColor
+            self.eventBox.modify_bg(gtk.STATE_NORMAL, color)
+            self.image.set_from_stock(image, gtk.ICON_SIZE_LARGE_TOOLBAR)
+            self.label.set_text(message)
+            self.eventBox.show_all()
+        else:
+            self.eventBox.hide_all()
+
+    #hide nicebar
+    def onClickNiceBar(self, widget, event):
+        self.eventBox.hide_all()
 
 class StatusCombo(gtk.ComboBox):
     '''this class represent the combo where you set the status'''
@@ -407,15 +447,13 @@ class StatusCombo(gtk.ComboBox):
         flag = False
         j = 0
         for i in controller.status_ordered[0]:
-            if self.controller.contacts.get_status() == i:
-                self.set_active(j)
-
-            if i != 'FLN':
-                self.statusListStore.append([
-                    self.controller.theme.statusToPixbuf(i).scale_simple(20,20,gtk.gdk.INTERP_BILINEAR), i,
+            if i not in self.controller.bad_statuses:
+                self.statusListStore.append([ \
+                    self.controller.theme.statusToPixbuf(i).scale_simple(20,20,gtk.gdk.INTERP_BILINEAR), i, \
                     _(self.controller.status_ordered[2][j])]) # re-gettext-it
             j += 1
 
+        self.set_current_status()
         # flag needed to avoid the double-changing of status when
         # user changes it from another place
         self.changeStatusFlag = True
@@ -424,21 +462,29 @@ class StatusCombo(gtk.ComboBox):
         self.connect('changed', self.on_status_changed, self.changeStatusFlag)
         self.controller.msn.connect('self-status-changed',
             self.selfStatusChanged)
-
+    
+    def set_current_status(self, status=None):
+        ''' sets current status in the widget '''
+        if status is None:
+            i = self.controller.contacts.get_status()
+            status = self.controller.status_ordered[0][i]
+        
+        i = 0
+        for item in self.statusListStore:
+            if item[1] == status:
+                break
+            i += 1
+            
+        self.set_active(i)
+        
     def selfStatusChanged(self, msnp, status):
         self.changeStatusFlag = False
-        statusOrdered = self.controller.status_ordered[1]
-
-        if emesenelib.common.reverse_status[status] in statusOrdered:
-            self.set_active(statusOrdered.index(\
-                emesenelib.common.reverse_status[status]))
-
+        self.set_current_status(status)        
         self.changeStatusFlag = True
 
     def on_status_changed(self , *args):
         if self.changeStatusFlag:
             asd = self.statusListStore.get(self.get_active_iter(), 1)
-            #print "on_status_changed", asd
             self.controller.contacts.set_status(asd[0])
 
     def on_scroll_event(self,button, event):
