@@ -185,9 +185,8 @@ class UserList(gtk.TreeView):
         self.connect("row-collapsed" , self.onRowCollapsed)
 
         self.last_fill = 0
-        if os.name != 'nt':  # gtk bug here?
-            self.model.set_sort_func(UserList.OBJ, self.sortMethod)
-            self.model.set_sort_column_id(UserList.OBJ, gtk.SORT_ASCENDING)
+        self.model.set_sort_func(UserList.OBJ, self.sortMethod)
+        self.model.set_sort_column_id(UserList.OBJ, gtk.SORT_ASCENDING)
 
     def compareContact(self, x, y, status, type):
         def _getPriority(status, contact):
@@ -525,7 +524,7 @@ class UserList(gtk.TreeView):
         (rowType, obj) = self.getSelected()
 
         if rowType == 'user' and obj:
-            return (rowType, obj.email, self.getGroupSelected().name, obj.id)
+            return (rowType, obj.email, self.getGroupSelected().name, obj.id, obj.blocked)
         elif rowType == 'group' and obj:
             return (rowType, obj.name, obj.id)
         else:
@@ -558,19 +557,19 @@ class UserList(gtk.TreeView):
         if contact.alias != '' and showAlias:
             label = contact.alias
         elif self.showByNick:
-            label = contact.nick
+            label = contact.nick.replace('\n', ' ')
         else:
             label = contact.email
-        psm = contact.personalMessage
+        psm = contact.personalMessage.replace('\n', ' ')
 
         hasSmilies = self.parseSmilies
         smallIcons = self.smallIcons
 
         if smallIcons and not tooltip:
             if not psm and not status:
-                template = self.userLabel.replace("\n", '')
+                template = self.userLabel.replace('\n', '')
             else:
-                template = self.userLabel.replace("\n", " - ")
+                template = self.userLabel.replace('\n', ' - ')
         else:
             template = self.userLabel
 
