@@ -21,8 +21,10 @@
 import os
 import gtk
 import gobject
-
+import paths
 import Avatar
+import urllib
+import Theme
 
 import abstract.stock as stock
 
@@ -94,11 +96,13 @@ def entry_cb(widget, window, response_cb, *args):
 
 def add_contact_cb(widget, window, response_cb, response):
     '''callback called when a button is selected on the add_contact dialog'''
+
+    alias = window.entryAlias.get_text()
     contact = window.entry.get_text()
-    group = window.combo.get_model().get_value(window.combo.get_active_iter(), 0)
+    group = window.groupComboEntry.get_children()[0].get_text()
 
     window.hide()
-    response_cb(response, contact, group)
+    response_cb(response, contact, group, alias)
 
 def set_picture_cb(widget, window, response_cb, response, path):
     '''callback called when a button is selected on the set_picture dialog'''
@@ -286,7 +290,7 @@ def contact_added_you(accounts, response_cb,
     means remind me later.'''
     raise NotImplementedError("This method isn't implemented")
 
-def add_contact(groups, group, response_cb, title=_("Add user")):
+def add_contact(groups, group, response_cb, genericAvatarPixbuf=None, title=_("Add user")):
     '''show a dialog asking for an user address, and (optional)
     the group(s) where the user should be added, the response callback
     receives the response type (stock.ADD, stock.CANCEL or stock.CLOSE)
@@ -294,51 +298,66 @@ def add_contact(groups, group, response_cb, title=_("Add user")):
     added (give a empty tuple if you don't implement this feature,
     the controls are made by the callback, you just ask for the email,
     don't make any control, you are just implementing a GUI! :P'''
+    #genericAvatarPixbuf has the blank avatar shown in the dialog
+
     window = new_window(title, response_cb)
+
     label = gtk.Label(_("Account"))
     label_align = gtk.Alignment(0.0, 0.5)
     label_align.add(label)
     entry = gtk.Entry()
+
+    labelAlias = gtk.Label(_("Alias"))
+    labelAlias_align = gtk.Alignment(0.0, 0.5)
+    labelAlias_align.add(labelAlias)
+    entryAlias = gtk.Entry()   
+
     group_label = gtk.Label(_("Group"))
+    groupsList = gtk.ListStore(gobject.TYPE_STRING)
+    groupComboEntry = gtk.ComboBoxEntry(groupsList, 0)
+    groupCompletion = gtk.EntryCompletion()
+    groupCompletion.set_model(groupsList)
+    groupComboEntry.get_children()[0].set_completion(groupCompletion)
+    groupCompletion.set_text_column(0)
+
     group_label_align = gtk.Alignment(0.0, 0.5)
     group_label_align.add(group_label)
-    combo = gtk.combo_box_new_text()
 
-    combo.append_text("")
+    #fill groups combo box
+    for i in groups:
+        groupsList.append([i])
 
-    groups = list(groups)
-    groups.sort()
-
-    selected = 0
-
-    for (index, group_name) in enumerate(groups):
-        combo.append_text(group_name)
-
-        if group == group_name:
-            selected = index + 1
-
-    combo.set_active(selected)
-
-    table = gtk.Table(2, 2)
+    table = gtk.Table(3, 2)
     table.attach(label_align, 0, 1, 0, 1)
     table.attach(entry, 1, 2, 0, 1)
-    table.attach(group_label_align, 0, 1, 1, 2)
-    table.attach(combo, 1, 2, 1, 2)
+    table.attach(labelAlias_align, 0, 1, 1, 2)
+    table.attach(entryAlias, 1, 2, 1, 2)
+    table.attach(group_label_align, 0, 1, 2, 3)
+    table.attach(groupComboEntry, 1, 2, 2, 3)
     table.set_row_spacings(2)
     table.set_col_spacings(8)
 
+    if genericAvatarPixbuf:
+        genericAvatar = gtk.Image()
+        genericAvatar.set_size_request(96, 96)
+        genericAvatar.set_from_pixbuf(genericAvatarPixbuf)
+        window.hbox.pack_start(genericAvatar, True, True)
+
     window.hbox.pack_start(table, True, True)
+    window.hbox.set_spacing(10)
 
     add_button(window, gtk.STOCK_CANCEL, stock.CANCEL, response_cb,
         add_contact_cb)
     add_button(window, gtk.STOCK_OK, stock.ACCEPT, response_cb,
         add_contact_cb)
 
+    setattr(window, 'entryAlias', entryAlias)
     setattr(window, 'entry', entry)
-    setattr(window, 'combo', combo)
+    setattr(window, 'groupComboEntry', groupComboEntry)
 
     entry.connect('activate', add_contact_cb, window, response_cb,
         stock.ACCEPT)
+    groupComboEntry.get_children()[0].connect('activate', add_contact_cb, window, response_cb, stock.ACCEPT)
     window.set_resizable(False)
     window.set_focus(entry)
     window.show_all()
@@ -399,10 +418,15 @@ def set_picture(controller, path_current, cache_path,
     else:
         _avatar_chooser.grab_focus()
 
-def set_custom_emoticon(ce_dir, response_cb):
+def set_custom_emoticon(ce_dir, response_cb, smilie_list):
     '''show a dalog to create a custome emotion, ce_dir is the
     directory where the image chooser dialog will open'''
-    CEChooser(ce_dir, response_cb).show()
+    CEChooser(ce_dir, response_cb, smilie_list).show()
+
+def show_profile(controller, nick, psm, currentAvatarPath, response_cb):
+    '''shows the user profile (nick, psm, avatar) and the
+    The user can change any of them'''
+    Profile(controller, nick, psm, currentAvatarPath, response_cb)
 
 def rename_group(name, response_cb, title=_("Rename group")):
     '''show a dialog with the group name and ask to rename it, the
@@ -665,7 +689,7 @@ class AddBuddy(gtk.Window):
     def cb_add(self, button):
         '''Callback when the add button is clicked'''
         mail, nick = self.mails[self.pointer]
-        self.controller.contacts.add(mail)
+        self.controller.contacts.add(mail, '')
         self.cb_cancel(None)
         
     def cb_rej(self, button):
@@ -673,6 +697,129 @@ class AddBuddy(gtk.Window):
         self.controller.contacts.remove_from_pending_list(mail)
         self.cb_cancel(None)
 
+class Profile(gtk.Window):
+    '''Dialog where user can change nick, psm and avatar'''
+    def __init__(self, controller, nick, psm, avatarPath, response_cb):
+        gtk.Window.__init__(self)
+
+        #window properties
+        self.set_border_width(10)
+        self.set_position(gtk.WIN_POS_CENTER)
+        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
+        self.set_resizable(False)
+
+        self.controller = controller
+        self.response_cb = response_cb
+        self.nick = nick
+        self.psm = psm
+        self.currentAvatarPath = avatarPath
+        self.newAvatarPath = avatarPath
+
+        #build the window
+        #nick and pm labels and entries
+        self.set_title(_('My profile'))
+        self.nickLabel=gtk.Label(_('Nick:'))
+        self.nickLabel.set_alignment(0.0,0.5)
+        self.nickEntry=gtk.Entry()
+        self.nickEntry.set_text(nick)
+        self.psmLabel=gtk.Label(_('Personal Message:'))
+        self.psmLabel.set_alignment(0.0,0.5)
+        self.psmEntry=gtk.Entry()
+        self.psmEntry.set_text(psm)
+        self.vbox = gtk.VBox()
+        self.vbox.add(self.nickLabel)
+        self.vbox.add(self.nickEntry)
+        self.vbox.add(self.psmLabel)
+        self.vbox.add(self.psmEntry)
+        self.vbox.set_size_request(300, -1)
+
+        #avatar frame
+        self.currentAvatar = gtk.Image()
+        self.currentAvatar.set_size_request(96, 96)
+        if os.path.exists(avatarPath):
+            pixbuf = gtk.gdk.pixbuf_new_from_file(avatarPath)
+            self.currentAvatar.set_from_pixbuf(pixbuf)
+        self.frame_current = gtk.Frame(_("Avatar"))
+        self.frame_current.add(self.currentAvatar)
+        self.avatarEventBox = gtk.EventBox()
+        self.avatarEventBox.add(self.frame_current)
+        self.hbox = gtk.HBox()
+        self.hbox.set_spacing(10)
+        self.hbox.add(self.avatarEventBox)
+        self.hbox.add(self.vbox)
+
+        #accept/cancel buttons
+        self.acceptButton = gtk.Button(stock=gtk.STOCK_OK)
+        self.cancelButton = gtk.Button(stock=gtk.STOCK_CANCEL)
+        self.buttonshbox = gtk.HButtonBox()
+        self.buttonshbox.set_layout(gtk.BUTTONBOX_END)
+        self.buttonshbox.add(self.cancelButton)
+        self.buttonshbox.add(self.acceptButton)
+
+        self.vbox2 = gtk.VBox()
+        self.vbox2.add(self.hbox)
+        self.vbox2.add(self.buttonshbox)
+
+        #connect signals
+        self.avatarEventBox.connect("button-press-event", self.choose_picture)
+        self.acceptButton.connect("clicked", self.on_accept)
+        self.cancelButton.connect("clicked", self.on_cancel)
+        self.connect('delete-event', self.on_close)
+        self.nickEntry.connect('activate', self.on_accept)
+        self.psmEntry.connect('activate', self.on_accept)
+        self.controller.connect('avatar-changed', self.updateAvatar)
+
+        #add everything to the window and show it
+        self.add(self.vbox2)
+        self.show_all()
+
+    #this method updates the avatar if it's changed using another method while the dialog is open
+    #but if the third parameter is not None, it can be called from other places
+    def updateAvatar(self, controller, path=None):
+        if path != None:
+            avatarPath = path
+        else:
+            avatarPath = controller.config.user['avatarPath']
+        if os.path.exists(avatarPath):
+            pixbuf = gtk.gdk.pixbuf_new_from_file(avatarPath)
+            self.currentAvatar.set_from_pixbuf(pixbuf)
+
+    #this method show the avatar chooser dialog and saves the new avatar if any
+    #this method does not change the actual avatar, just the dialog's avatar
+    def choose_picture(self, widget, event):
+        def _on_picture_selected(response, path):
+            if response == stock.ACCEPT and path != self.currentAvatarPath:
+                self.newAvatarPath = path
+                self.updateAvatar(self.controller,path)
+
+        avatar_cache = self.controller.config.getAvatarsCachePath()
+        set_picture(self.controller, self.currentAvatarPath, avatar_cache, _on_picture_selected)
+
+    #if nick, psm or avatar was changed, callback the new values
+    def on_accept(self, button):
+        '''method called when the user clicks the button'''
+        
+        newNick = self.nickEntry.get_text()
+        newPsm = self.psmEntry.get_text()
+        
+        if self.nick != newNick or self.psm != newPsm or self.currentAvatarPath != self.newAvatarPath:
+            self.destroy()
+            self.response_cb(stock.ACCEPT, newNick, newPsm, self.newAvatarPath)
+        else:
+            self.destroy()
+            self.response_cb(stock.CANCEL, '', '', '')
+
+    def on_cancel(self, button):
+        '''method called when the user clicks the button'''
+        self.destroy()
+        self.response_cb(stock.CANCEL, '', '', '')
+
+    def on_close(self, window, event):
+        '''called when the user click on close'''
+        self.destroy()
+        self.response_cb(stock.CLOSE, '', '', '')
+
+
 class AvatarChooser(gtk.Window):
     '''A dialog to choose an avatar'''
 
@@ -689,7 +836,7 @@ class AvatarChooser(gtk.Window):
         self.cache_path = cache_path
 
         self.set_title(_("Avatar chooser"))
-        self.set_default_size(600, 400)
+        self.set_default_size(602, 400)
         self.set_border_width(4)
         self.set_position(gtk.WIN_POS_CENTER)
         self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
@@ -902,7 +1049,7 @@ class AvatarChooser(gtk.Window):
                 except Exception, e:
                     error(str(e))
 
-        ImageChooser(os.path.expanduser('~'), _on_image_selected).show()
+        ImageChooser(paths.HOME_DIR, _on_image_selected).show()
 
     def _on_remove(self, event):
         '''Removes the selected avatar'''
@@ -1102,7 +1249,7 @@ class CEChooser(ImageChooser):
     SMALL = _("small (16x16)")
     BIG = _("big (50x50)")
 
-    def __init__(self, path, response_cb):
+    def __init__(self, path, response_cb, smilie_list):
         '''class constructor'''
         ImageChooser.__init__(self, path, None)
 
@@ -1112,18 +1259,39 @@ class CEChooser(ImageChooser):
         self.shortcut = gtk.Entry()
         self.combo = gtk.combo_box_new_text()
 
+        tooltip_t = _("You can add an emoticon also by entering the url of a png/gif image.")
+
+        labelurl = gtk.Label(_("Or enter an image url"))
+        labelurl.set_tooltip_text(tooltip_t)
+        self.url = gtk.Entry()
+
         self.combo.append_text(CEChooser.SMALL)
         self.combo.append_text(CEChooser.BIG)
         self.combo.set_active(0)
 
-        hbox = gtk.HBox()
+        hbox0 = gtk.HBox()
+        hbox1 = gtk.HBox()
+        vbox1 = gtk.VBox()
+        vbox2 = gtk.VBox()
 
-        hbox.add(label)
-        hbox.add(self.shortcut)
-        hbox.add(self.combo)
+        hbox1.add(self.shortcut)
+        hbox1.add(self.combo)
 
-        self.vbox.pack_start(hbox, False)
-        hbox.show_all()
+        vbox2.add(self.url)
+        vbox2.add(hbox1)
+
+        vbox1.add(labelurl)
+        vbox1.add(label)
+
+        hbox0.add(vbox1)
+        hbox0.add(vbox2)
+
+        self.vbox.pack_start(hbox0, False)
+        hbox0.show_all()
+
+        self.shortcut.connect('changed', self._on_changed)
+
+        self.smilie_list = smilie_list
 
     def _on_accept(self, button):
         '''method called when the user clicks the button'''
@@ -1131,14 +1299,29 @@ class CEChooser(ImageChooser):
         shortcut = self.shortcut.get_text()
         size = self.combo.get_model().get_value(self.combo.get_active_iter(), 0)
 
-        if os.path.isfile(filename):
+        URL = self.url.get_text()
+        if URL[:4] == 'www.':
+            	    URL = 'http://'+URL
+        ENDEXT = URL.endswith('.gif') or URL.endswith('.png')
+        if URL.startswith('http://') and ENDEXT == True:
             if not shortcut:
                 error(_("Empty shortcut"))
             else:
+                NAME = URL.split('/')[-1]
+                DEST = paths.SMILIES_HOME_PATH + NAME
+                emoticonimg = urllib.urlretrieve(URL, DEST)
                 self.hide()
-                self.response_cb(stock.ACCEPT, filename, shortcut, size)
+                self.response_cb(stock.ACCEPT, DEST, shortcut, size)
+                os.remove(DEST)
         else:
-            error(_("No picture selected"))
+            if os.path.isfile(filename):
+                if not shortcut:
+                    error(_("Empty shortcut"))
+                else:
+                    self.hide()
+                    self.response_cb(stock.ACCEPT, filename, shortcut, size)
+            else:
+                error(_("No picture selected"))
 
     def _on_cancel(self, button):
         '''method called when the user clicks the button'''
@@ -1150,6 +1333,16 @@ class CEChooser(ImageChooser):
         self.hide()
         self.response_cb(stock.CLOSE, None, None, None)
 
+    def _on_changed(self, shortcut):
+        '''called when the text in self.shortcut changes'''
+
+        SHORTCUT = self.shortcut.get_text()
+
+        if SHORTCUT in self.smilie_list:
+            self.shortcut.set_property('secondary-icon-stock', gtk.STOCK_DIALOG_ERROR)
+        else:
+            self.shortcut.set_property('secondary-icon-stock', None)
+
 def get_filename(self):
     '''Shortcut to get a properly-encoded filename from a file chooser'''
     filename = self.file_chooser.get_filename()
