@@ -97,42 +97,34 @@ class ProfileManager(gobject.GObject):
 
         if response.status[0] == 200:
             self.newCacheFile(self.user + '_ab.xml', response.body)
-            return True
-        else:
-            return False
 
-    def onGetDynamicItems(self, response):
-
-        if response.status[0] == 200:
-            self.newCacheFile(self.user + '_di.xml', response.body)
-
-            self.setDynamicItemsXml(response.body)
-            self.changeNick(getNickFromDynamicItems(response.body),
-                initial=True)
-            self.emit('user-list-change')
+            self.setAddressBookXml(response.body)
+            self.cid = getCIDFromDynamicItems(response.body)
+            self.emit('login-successful')
 
             return True
         else:
             return False
 
-    def getUserProfile(self, email, storageAuthCache = None):
-        if storageAuthCache == None:
-            self.getStorageAuthCache(email)
-        else:
-            common.debug('request user profile ' + email)
+    def onGetProfile(self, response):
+        if response.status[0] != 200:
+            self.affinityCache = ''
+            self.rid = ''
+            return
+        try:
+            nick = response.body.split('</DisplayName>')[0].split('<DisplayName>')[1]
+        except: # yes, someone doesn't have a nickname, it seems --c10ud
+            nick = ''
+        try: # okay, this uglyness is not pablo's fault, i confess --c10ud
+            pm = response.body.split('</PersonalStatus>')[0].split('<PersonalStatus>')[1]
+        except:
+            pm = ''        
+        self.changeNick(nick, initial=True)
+        self.changePersonalMessage(pm)
+        self.affinityCache = response.body.split('</CacheKey>')[0].split('<CacheKey>')[1]
+        self.rid = response.body.split('</ResourceID>')[0].split('<ResourceID>')[1]
 
-            cid = str(self.contactManager.getContact(email).cid)
-            soap.manager.do_request(self.proxy,\
-                'http://www.msn.com/webservices/spaces/v1/GetXmlFeed', \
-                'cid-580B3F2402D4CDA4.cc.services.spaces.live.com', 80, \
-                '/contactcard/contactcardservice.asmx', \
-                soap.templates.space % (self.t, "", cid, storageAuthCache, "en-US"), \
-                self.onGetUserProfile)
-
-    def onGetUserProfile(self, response):
-        common.debug(str(response.status) + "\n" + response.body)
-
-    def addUser(self, email, group):
+    def addUser(self, email, group, *callback_and_args):
         '''add an user to the friend list'''
 
         if self.contactManager.contact_exists(email):
@@ -144,9 +136,10 @@ class ProfileManager(gobject.GObject):
 
         # need to add it in prevention of ILN. Don't update user list
         self.contactManager.addNewContact(email)
-        soap.requests.add_contact(self.proxy, email, self.onUserAdded, email, group)
+        soap.requests.add_contact(self.proxy, email, self.onUserAdded, email, \
+            group, callback_and_args)
 
-    def onUserAdded(self, response, email, group=''):
+    def onUserAdded(self, response, email, group, *callback_and_args_triple):
         '''this method is called when the addUser soapRequest get a response'''
 
         common.debug('add user: ' + email + ' ' + str(response.status))
@@ -163,6 +156,10 @@ class ProfileManager(gobject.GObject):
             else:
                 # once we now the id we can add it to a group
                 self.addUserToGroup(email, group)
+            if len(callback_and_args_triple[0]) == 3: # alias hack foo(bar, lol)
+                func, acco, alias = callback_and_args_triple[0]
+                if alias != '':
+                    func(acco, alias)
         else:
             self.contactManager.removeContact(email)
             self.emit('user-list-change')
@@ -416,7 +413,7 @@ class ProfileManager(gobject.GObject):
 
         soap.manager.do_request(self.proxy,\
             'http://www.msn.com/webservices/AddressBook/ABGroupAdd',
-            'omega.contacts.msn.com', 443, '/abservice/abservice.asmx',
+            'contacts.msn.com', 443, '/abservice/abservice.asmx',
             soap.templates.addGroup % (group,),
             self.onGroupAdded, (group,))
 
@@ -448,7 +445,7 @@ class ProfileManager(gobject.GObject):
 
             soap.manager.do_request(self.proxy,\
                 'http://www.msn.com/webservices/AddressBook/ABGroupDelete', \
-                'omega.contacts.msn.com', 443, '/abservice/abservice.asmx', \
+                'contacts.msn.com', 443, '/abservice/abservice.asmx', \
                 soap.templates.deleteGroup % (gid,), \
                 self.onGroupRemoved, (gid, groupObj))
 
@@ -490,7 +487,7 @@ class ProfileManager(gobject.GObject):
             self.emit('group-attr-changed', objOldGroup, group)
             soap.manager.do_request(self.proxy,\
                 'http://www.msn.com/webservices/AddressBook/ABGroupUpdate', \
-                'omega.contacts.msn.com', 443, '/abservice/abservice.asmx', \
+                'contacts.msn.com', 443, '/abservice/abservice.asmx', \
                 soap.templates.renameGroup % (gid, common.escape(newGroup)), \
                 self.onGroupRenamed, (oldGroup, newGroup))
 
@@ -530,8 +527,9 @@ class ProfileManager(gobject.GObject):
 
         self.socket.sendCommand("PRP", "MFN " + urllib.quote(nick))
 
-        if not initial:
-            soap.requests.change_nick(self.proxy, nick, self.onNickChanged, oldNick)
+        if not initial and self.affinityCache != '':
+            soap.requests.update_profile(self.proxy, self.affinityCache, \
+                self.rid, nick, self.personalMessage, self.onNickChanged, oldNick)
 
     def changeAlias(self, user, alias):
         alias = alias.decode('utf-8', 'replace').encode('utf-8')
@@ -551,6 +549,12 @@ class ProfileManager(gobject.GObject):
             self.emit('error', 'nick-change-error',
                 common.parseSoapFault(response))
 
+    def onPmChanged(self, response, oldPm):
+        if response.status[0] != 200:
+            self.emit('self-personal-message-changed', self.personalMessage, oldPm)
+            self.emit('error', 'pm-change-error',
+                common.parseSoapFault(response))
+
     def onAliasChanged(self, response, user, oldAlias):
         if response.status[0] != 200:
             self.emit('contact-attr-changed', user, 'alias', oldNick)
@@ -575,8 +579,14 @@ class ProfileManager(gobject.GObject):
     def changePersonalMessage(self, pm):
         '''change the personal message'''
         if self.personalMessage != pm:
+            if len(pm) > 129:
+                return
+            oldPm = self.personalMessage
             self.personalMessage = pm
             self.updateUUX()
+            if self.affinityCache != '':
+                soap.requests.update_profile(self.proxy, self.affinityCache, \
+                    self.rid, self.nick, self.personalMessage, self.onPmChanged, oldPm)
             self.emit('self-personal-message-changed', self.user, pm)
         else:
             common.debug("duplicate pm")
@@ -603,19 +613,16 @@ class ProfileManager(gobject.GObject):
             else:
                 return self.contactManager.getContactNick(mail)
 
-
-    # almost complete deltas implementation below, omg
-
-    def setDynamicItemsXml(self, xml):
+    def setAddressBookXml(self, xml):
         '''modify the structure with a new DynamicItems xml'''
-        #print "2"
-        #print xml
+
         contacts = {}
-        
+
         for (mail, contact) in self.contactManager.contacts.iteritems():
             contacts[mail] = contact
-        
+
         self.contactManager.groups = {}
+        self.contactManager.noGroup.users = {}
         self.contactManager.contacts = {}
 
         #doc = minidom.parseString(xml)
@@ -695,8 +702,7 @@ class ProfileManager(gobject.GObject):
     def setMembershipListXml(self, xml):
         '''modify the structure with a new MembershipList xml
         if it is the first xml that you send, send first the dynamic items'''
-        #print "1"
-        #print xml
+
         self.contactManager.lists['Allow'] = []
         self.contactManager.lists['Block'] = []
         self.contactManager.lists['Reverse'] = []
@@ -725,11 +731,11 @@ class ProfileManager(gobject.GObject):
 
 gobject.type_register(ProfileManager)
 
-def getNickFromDynamicItems(xml):
+def getCIDFromDynamicItems(xml):
     try:
-        nick = xml.split('<contactType>Me</contactType>')\
-                [1].split('</displayName>')[0].split('<displayName>')[1]
-        return common.unescape(nick)
+        cid = xml.split('<contactType>Me</contactType>')\
+                [1].split('</CID>')[0].split('<CID>')[1]
+        return cid
     except IndexError:
         return ''
 
