@@ -99,6 +99,7 @@ class BaseSocket(BaseConnection):
     def __init__(self, host, port):
         BaseConnection.__init__(self)
 
+        self.error = ''
         # the buffer to store the received data
         self._buffer = ''
         self._host = host
@@ -174,7 +175,6 @@ class Socket(BaseSocket):
         
         self.inQueue = Queue.Queue(0)
         self.outQueue = Queue.Queue(0)
-        self.error = ''
         
         self.thread = SocketThread(self, host, port)
         self.thread.start()
@@ -218,6 +218,7 @@ class Socket(BaseSocket):
     def close(self):
         self.thread.quit()
         self.disconnectAll()
+        self.thread.join()
         self.thread = None
 
 
@@ -359,6 +360,8 @@ class SocketThread(BaseThread):
         
         if chunk == '\n':
             output.write(chunk)
+        if chunk == '':
+            self.signal('hangup')
 
         output.seek(0)
         return output.read()[:-2]
