@@ -59,10 +59,10 @@ class Msnp(ProfileManager.ProfileManager):
         'user-list-change' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, ()),
         # when an error happen this signal is emitted with the error name
         # and the description
-        'error' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, 
+        'error' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_STRING)),
         # an exception in msn.process, the arg is an exception object
-        'exception' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, 
+        'exception' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_PYOBJECT,)),
         # when we receive a message, the parameter is the user mail
         'message-received' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,)),
@@ -90,7 +90,7 @@ class Msnp(ProfileManager.ProfileManager):
             (gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING)),
         # command, tid, params, email, nick
         'add-notification' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
-            (gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING, 
+            (gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING,
              gobject.TYPE_STRING, gobject.TYPE_STRING)),
         'remove-notification' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING, \
@@ -113,14 +113,14 @@ class Msnp(ProfileManager.ProfileManager):
             (gobject.TYPE_STRING,gobject.TYPE_STRING)),
         'self-current-media-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)),
-        
+
         'new-conversation' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)),
         'new-switchboard' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_PYOBJECT,)),
         'nudge-received' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,)),
-            
+
         'initial-mail-notification' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             ()),
         # From, FromAddr, Subject, MessageURL , PostURL, id
@@ -128,7 +128,7 @@ class Msnp(ProfileManager.ProfileManager):
             (gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING)),
         'mail-movement-notification' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             ()),
-            
+
         'nick-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_STRING)),
         # email, status
@@ -144,27 +144,27 @@ class Msnp(ProfileManager.ProfileManager):
             (gobject.TYPE_STRING,)),
         'send-message-error' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING)),
-            
+
         'offline-message-waiting' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_PYOBJECT,)),
         'offline-message-received' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_PYOBJECT,)),
-        
+
         # switchboard, msnobj, email
-        'display-picture-changed' : (gobject.SIGNAL_RUN_LAST, 
-            gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT, 
+        'display-picture-changed' : (gobject.SIGNAL_RUN_LAST,
+            gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,
                     gobject.TYPE_PYOBJECT, gobject.TYPE_PYOBJECT,)),
         'custom-emoticon-transfered' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_PYOBJECT,gobject.TYPE_STRING)),
-        
+
         # switchboard, msnobj, email, directory
         'wink-transferred' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_PYOBJECT,gobject.TYPE_STRING)),
         # contact object, switchboard (it can be None, check it)
-        'hidden-contact' : (gobject.SIGNAL_RUN_LAST, 
-            gobject.TYPE_NONE, 
+        'hidden-contact' : (gobject.SIGNAL_RUN_LAST,
+            gobject.TYPE_NONE,
             (gobject.TYPE_PYOBJECT, gobject.TYPE_PYOBJECT)),
-        
+
         # login
         'login-error': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_PYOBJECT, )),
@@ -177,8 +177,13 @@ class Msnp(ProfileManager.ProfileManager):
         'switchboard' : (gobject.SIGNAL_RUN_LAST | gobject.SIGNAL_DETAILED, \
           gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT, ) * 3),
 
+        # used for sounds and notifications, bad hack
+        'new-file-transfer' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+            (gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT,)),
+        'finished-file-transfer' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+            (gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT)),
     }
-    
+
     ## constants (ftw!)
 
     # don't change this unless you know what you are doing
@@ -191,12 +196,12 @@ class Msnp(ProfileManager.ProfileManager):
     CLIENT_ID |= 0x8000  # winks
     CLIENT_ID |= 0x40000 # voice clips
     # TODO: ADD WEBCAM IF USER PREFERENCE TELL TO SHOW AND IMPORT WEBCAMDEVICE DOESN'T GIVE ERRORS
-    
+
     def __init__(self, host, port, user, password, \
-        userConfigDir, proxy = None, safemode = False, canUseP4=False):
+        userConfigDir, proxy = None, canUseP4=False):
         '''Constructor, intialize variables.'''
         gobject.GObject.__init__(self)
-        
+
         if proxy == None:
             self.socket = Socket.Socket(host, port)
         else:
@@ -208,17 +213,15 @@ class Msnp(ProfileManager.ProfileManager):
         self.tokens = {}
 
         self.cacheDir = userConfigDir + os.sep + 'cache'
-        
+
         self.userConfigDir = userConfigDir
 
         self.proxy = proxy
-        self.safemode = safemode
         self.callbacks = None
         self.connected = False
         self.nick = ''
 
         self.status = 'FLN'
-        self.lastCommand = ''
 
         self.switchboards = [] # the switchboards to process
         self.switchboardsByTid = {}
@@ -226,6 +229,8 @@ class Msnp(ProfileManager.ProfileManager):
         self.signals = [] # gobject signals to disconnect on logout
         self.selfSignals = [] # msnp signals
 
+        self.affinityCache = ''
+
         self.contactManager = ContactData.ContactList({})
         self.msnObjectsManager = Msnobj.MsnObjectsManager(user)
         self.msnOIM = MsnOIM.MsnOIM(self)
@@ -234,10 +239,10 @@ class Msnp(ProfileManager.ProfileManager):
 
         self.currentMedia = ''
         self.personalMessage = ''
-        
+
         self.msnobj = None # the msnobj for the display picture
         self.picture = None
-        
+
         self.inboxMessages = 0
         self.inboxUnreadMessages = 0
         self.otherMessages = 0
@@ -245,7 +250,7 @@ class Msnp(ProfileManager.ProfileManager):
 
         self.initialBLPTid = 0
         self.accountConfirmed = False
-       
+
         self._expecting = ''
         self._allowedRedirects = 5
         self._onLogin = False
@@ -285,7 +290,7 @@ class Msnp(ProfileManager.ProfileManager):
             return
 
         self._expecting = 'VER'
-    
+
     def _loginHangupHandler(self, socket):
         if self.socket.error:
             self.emit('login-error', 'Connection problem: ' + self.socket.error)
@@ -307,17 +312,17 @@ class Msnp(ProfileManager.ProfileManager):
 
         if retval == False:
             self.socket.disconnectAll()
-    
+
     def _loginProcess(self, socket):
         '''Called when a message is received on the login phase'''
-        
+
         (command, tid, params) = self.socket.receiveCommand()
 
         # messages that may be received at any time
         # including XFR, GCF, MSG
         if command == 'XFR' and params[ :2 ] == 'NS':
             # XFR 3 NS 207.46.24.39:1863 U D
-            
+
             try:
                 ns = params.split()[1].split(":") # 207.46.24.39:1863
                 host = ns[0]                      # 207.46.24.39
@@ -325,7 +330,7 @@ class Msnp(ProfileManager.ProfileManager):
             except:
                 self.emit('login-error', 'Incorrect parameters: ' + params)
                 return
-            
+
             if (self._allowedRedirects - 1) <= 0:
                 self.emit('login-error', 'Too many redirects')
                 return
@@ -335,10 +340,12 @@ class Msnp(ProfileManager.ProfileManager):
         elif command == 'MSG':
             data = self.socket.receivePayload(int(params.split()[-1]))
             if self.parse_demographics(data):
-                self.emit('login-successful')
+                self._retriveLists()
                 return
         elif command == 'GCF':
-            self.socket.receivePayload(int(params))
+            data = self.socket.receivePayload(int(params))
+            # this data contains base64 encoded regexps that are used 
+            # by microsoft for censoring unwanted text, say malware links, etc. 
         elif command == 'SBS':
             pass
         elif self._expecting and self._expecting != command:
@@ -354,7 +361,7 @@ class Msnp(ProfileManager.ProfileManager):
                 if not params.startswith('MSNP15'):
                     self.emit('login-error', 'Protocol not supported by server')
                     return False
-                
+
                 self.socket.sendCommand("CVR", Msnp.CVR_STRING % self.user)
                 self._expecting = 'CVR'
             elif command == 'CVR':
@@ -386,9 +393,9 @@ class Msnp(ProfileManager.ProfileManager):
                 # other USR, maybe fail
                 self.emit('login-error', 'Authentication error')
                 return False
-        
+
         return True
-    
+
     def do_login_error(self, message):
         common.debug("login error ;_;", 'core')
         common.debug(message, 'core')
@@ -398,7 +405,7 @@ class Msnp(ProfileManager.ProfileManager):
             pass
         self._onLogin = False
 
-    def do_login_successful(self):
+    def _retriveLists(self):
         '''logged in :D'''
 
         common.debug("logged in", 'core')
@@ -406,23 +413,23 @@ class Msnp(ProfileManager.ProfileManager):
 
         self.soapManager = soap.manager.SoapManager(self)
         self.soapManager.start()
-        
+
         # disable login process
         self.socket.disconnectAll()
 
         # get sockets working
         self.socket.connect('input', self.process)
         self.socket.connect('hangup', self.socketHangup)
-        
+
         # aarrrrghhhh
         self.signals.append(gobject.timeout_add(500, self.soapManager.process))
         self.signals.append(gobject.timeout_add(5000, self.checkPing))
-        
+
         # Get the lists
-        mlCache = self.getCacheFileData(self.user + "_ml.xml")
-        diCache = self.getCacheFileData(self.user + "_di.xml")
+        mlCache = None #self.getCacheFileData(self.user + "_ml.xml")
+        diCache = None #self.getCacheFileData(self.user + "_di.xml")
         
-        if mlCache and diCache and not self.safemode:
+        if mlCache and diCache:
             common.debug("parsing membership list", 'core')
             start = time.time()
             try:
@@ -437,36 +444,6 @@ class Msnp(ProfileManager.ProfileManager):
                 common.debug("done:" + str(time.time() - start), 'core')
             except Exception, e: #TODO: pylint
                 print "error parsing lists", e
-                soap.requests.membership(self.onGetMembershipList, sync=True)
-                soap.requests.dynamic_items(self.onGetDynamicItems, sync=True)
-
-            self.emit('user-list-change')
-        else:
-            soap.requests.membership(self.proxy, self.onGetMembershipList, sync=True)
-            soap.requests.dynamic_items(self.proxy, self.onGetDynamicItems, sync=True)
-
-        # send privacy status
-        self.initialBLPTid = self.socket.sendCommand("BLP" , "BL")
-        # if it gets a 209 reply, the account is unconfirmed
-        
-        # send our contacts
-        if not self.safemode:
-            # TODO: flooding with this killed someones router
-            for i in self.contactManager.getADL():
-                self.socket.sendPayloadCommand("ADL", '', i)
-        else:
-            def safeADL(chunk, next):
-                self.socket.sendPayloadCommand("ADL", '', chunk)
-                if next:
-                    gobject.idle_add(safeADL, next.pop(0), next)
-                return False
-
-            ADLChunks = self.contactManager.getADL()
-            if ADLChunks:
-                safeADL(ADLChunks.pop(0), ADLChunks)
-        
-        # change the nickname
-        self.changeNick(self.nick, initial=True)
 
         # connect some callbacks
         self.callbacks = SignalHandler.SignalHandler(self)
@@ -478,13 +455,27 @@ class Msnp(ProfileManager.ProfileManager):
         self.selfSignals.append(self.connect('server-message', \
             self.callbacks.serverMessage))
 
-        if mlCache and diCache and not self.safemode:
-            soap.requests.membership(self.proxy, self.onGetMembershipList, sync=False)
-            soap.requests.dynamic_items(self.proxy, self.onGetDynamicItems, sync=False)
+        soap.requests.membership(self.proxy, self.onGetMembershipList)
+        soap.requests.address_book(self.proxy, self.onGetAddressBook)
+
+    def do_login_successful(self):
+        # send privacy status
+        self.initialBLPTid = self.socket.sendCommand("BLP" , "BL")
+        # if it gets a 209 reply, the account is unconfirmed
+        
+        # send our contacts
+        # TODO: flooding with this killed someones router
+        for i in self.contactManager.getADL():
+            self.socket.sendPayloadCommand("ADL", '', i)
+
+        # change the nickname
+        self.changeNick(self.nick, initial=True)
+        soap.requests.get_profile(self.proxy, self.cid, self.onGetProfile)
 
     def passportReAuth(self, hash=None):
         if hash == None:
             hash = self.hash
+        
         self.passportid = self.passportAuth(hash)
         self.MSPAuth = self.passportid.split('&p')[0][2:]
         self.MSPProf = self.passportid.split('&p')[1]
@@ -493,7 +484,7 @@ class Msnp(ProfileManager.ProfileManager):
         '''do the passport authenticaton, this is done connecting
         to loginnet.passport.com:443 and sending a XML message described
         on soap.templates.passport'''
-        
+
         common.debug('PASSPORT begin', 'core')
 
         # replace the %s in the string
@@ -525,33 +516,33 @@ class Msnp(ProfileManager.ProfileManager):
             for i in range(3):
                 try:
                     if self.proxy and self.proxy.host:
-                      proxy_connect = 'CONNECT %s:%s HTTP/1.0\r\n'%(_server,'443')
-                      user_agent = 'User-Agent: python\r\n'
-                      if self.proxy.user:
-                          # setup basic authentication
-                          user_pass = base64.encodestring(self.proxy.user+':'+self.proxy.password).replace('\n','')
-                          proxy_authorization = 'Proxy-authorization: Basic '+user_pass+'\r\n'
-                          proxy_pieces = proxy_connect+proxy_authorization+user_agent+'\r\n'
-                      else:
-                          proxy_pieces = proxy_connect+user_agent+'\r\n'
-                      # now connect, very simple recv and error checking
-                      proxy = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
-                      proxy.connect((self.proxy.host,int(self.proxy.port)))
-                      proxy.sendall(proxy_pieces)
-                      response = proxy.recv(8192) 
-                      status=response.split()[1]
-                      if status!=str(200):  raise 'Error status=',str(status)
+                        proxy_connect = 'CONNECT %s:%s HTTP/1.0\r\n'%(_server,'443')
+                        user_agent = 'User-Agent: python\r\n'
+                        if self.proxy.user:
+                            # setup basic authentication
+                            user_pass = base64.encodestring(self.proxy.user+':'+self.proxy.password).replace('\n','')
+                            proxy_authorization = 'Proxy-authorization: Basic '+user_pass+'\r\n'
+                            proxy_pieces = proxy_connect+proxy_authorization+user_agent+'\r\n'
+                        else:
+                            proxy_pieces = proxy_connect+user_agent+'\r\n'
+                        # now connect, very simple recv and error checking
+                        proxy = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
+                        proxy.connect((self.proxy.host,int(self.proxy.port)))
+                        proxy.sendall(proxy_pieces)
+                        response = proxy.recv(8192) 
+                        status=response.split()[1]
+                        if status!=str(200):  raise 'Error status=',str(status)
 
-                      # trivial setup for ssl socket
-                      if HAVE_PY25:
-                          sslconn = socket.ssl(proxy, None, None)
-                          sock = httplib.FakeSocket(proxy, sslconn)
-                      else:
+                        # trivial setup for ssl socket
+                        if HAVE_PY25:
+                            sslconn = socket.ssl(proxy, None, None)
+                            sock = httplib.FakeSocket(proxy, sslconn)
+                        else:
                             sock = ssl.wrap_socket(proxy, None, None)
-                      conn = httplib.HTTPConnection('localhost')
-                      conn.sock = sock
+                        conn = httplib.HTTPConnection('localhost')
+                        conn.sock = sock
                     else:
-                      conn = httplib.HTTPSConnection(_server,443)
+                        conn = httplib.HTTPSConnection(_server,443)
                     conn.request("POST", _url, body, headers)
                     response = conn.getresponse()
                     common.debug('%s %s'%(response.status, response.reason), \
@@ -578,7 +569,7 @@ class Msnp(ProfileManager.ProfileManager):
             else:
                 succeeded = True
                 break
-        
+
         if not succeeded:
             raise common.AuthError, 'Too many redirections'
 
@@ -608,18 +599,18 @@ class Msnp(ProfileManager.ProfileManager):
             self.socket.ping()
         except (IOError, socket.error):
             self.emit('connection-closed')
-            
+
     def checkConnection(self):
         '''return true if the time between the last ping and the response is
         lower than max_ping_delay'''
-        
+
         if self.socket.ping_enabled and \
            (self.socket.lastqng < self.socket.lastpng) and \
            (time.time() - self.socket.lastpng) > self.socket.max_ping_delay:
             return False
-        
+
         return True
-    
+
     def checkPing(self):
         '''check connection and ping if needed
         A return value False doesn't mean broken connection,
@@ -649,7 +640,7 @@ class Msnp(ProfileManager.ProfileManager):
 
     def process(self, obj=None):
         '''read a command from the server and process it'''
-        
+
         (command, tid, params) = self.socket.receiveCommand()
         try:
             self.processCommand(command, tid, params)
@@ -658,7 +649,7 @@ class Msnp(ProfileManager.ProfileManager):
             self.emit('exception', sys.exc_info())
             return False
         return True
-    
+
     def processCommand(self, command, tid, params):
         if command == 'CHL':
             self.callbacks.challenge(self, command, tid, params)
@@ -668,8 +659,8 @@ class Msnp(ProfileManager.ProfileManager):
             self.callbacks.statusChange(self, command, tid, params)
             gobject.idle_add(self.emit, 'initial-status-change', command, tid, params)
         elif command == 'NLN':
+            # kids, we emit the status-online signal in SignalHandler            
             self.callbacks.statusOnline(self, command, tid, params)
-            self.emit('status-online', command, tid, params)
         elif command == 'FLN':
             self.callbacks.statusOffline(self, command, tid, params)
             self.emit('status-offline', command, tid, params)
@@ -682,22 +673,27 @@ class Msnp(ProfileManager.ProfileManager):
                 # <ml><d n="gmail.com"><c n="luismarianoguerra" t="1" l="8" \
                 # f="[Mariano%20Guerra]%20(IRC%20is%20just%20multiplayer%20 \
                 # notepad.)" /></d></ml>
-                
+
                 email = payload.split('<c n="')[1].split('"')[0] + '@' + \
                     payload.split('<ml><d n="')[1].split('"')[0]
                 nick = ''
-                
+
+                type = payload.split(' t="')[1].split('"')[0]
+                if int(type) == 32:
+                    print payload
+                    return
+
                 try:
                     nick = payload.split(' f="')[1].split('"')[0]
                     nick = urllib.unquote(nick)
                 except:
                     pass
-                
+
                 lists = self.contactManager.lists
                 if email not in lists['Block'] and email not in lists['Allow']:
                     self.emit('add-notification', command, tid, params, \
                         email, nick)
-                    
+
         elif command == 'RML':
             if params != 'OK':
                 payload = self.socket.receivePayload(int(params))
@@ -720,7 +716,7 @@ class Msnp(ProfileManager.ProfileManager):
                     self.parseUBX(command, tid, params, payload)
                 except Exception, e:
                     common.debug('Unable to handle UBX: ' + str(e))
-                
+
         elif command == 'XFR':
             #XFR 32 SB 65.54.171.31:1863 CKI 1743299383.52212212.219110167 U messenger.msn.com\r\n
             connstring = ' '.join([command, tid, params])
@@ -745,8 +741,6 @@ class Msnp(ProfileManager.ProfileManager):
             self.accountConfirmed = False
             self.emit('account-unconfirmed')
 
-        self.lastCommand = command
-    
     def parseUBX(self, command, tid, params, payload):
         '''this function parses the UBX payload, and sets the personal
         message or current media'''
@@ -757,22 +751,21 @@ class Msnp(ProfileManager.ProfileManager):
             self.contactManager.setContactPersonalMessage(tid, media)
         else:
             self.contactManager.setContactPersonalMessage(tid, parsed.psm)
-        
-        if self.lastCommand != 'ILN':
-            #TODO: is this signal needed?
-            self.emit('personal-message-changed', tid, parsed.psm)
-            
-            contact = self.contactManager.getContact(tid)
-            self.emit('user-attr-changed', contact)
-        
+
+        #TODO: is this signal needed?
+        self.emit('personal-message-changed', tid, parsed.psm)
+
+        contact = self.contactManager.getContact(tid)
+        self.emit('user-attr-changed', contact)
+
     def changeStatus(self , status):
         '''change the current status'''
-        
+
         if status == 'FLN' or status == 'offline':
             return
-        
+
         msnobj = ''
-        
+
         if self.msnobj:
             msnobj = ' ' + self.msnobj.quote()
         else:
@@ -808,13 +801,13 @@ class Msnp(ProfileManager.ProfileManager):
         RL Reverse List Users who added you to their contact list
         AL Allow List Users who are able to see your status
         BL Block List Users who are blocked from seeing your status'''
-        
+
         payloads = self.contactManager.buildDL(usersdict, initial=False)
 
         # TODO: flooding with this killed someones router
         for payload in payloads:
             self.socket.sendPayloadCommand(command, '', payload)
-        
+
     def logout(self):
         '''disconnect from the server'''
         self.emit('logout')
@@ -829,16 +822,16 @@ class Msnp(ProfileManager.ProfileManager):
             return
         self.connected = False
 
-        
+
         # cleanup references
         for signal in self.signals:
             gobject.source_remove(signal)
         self.signals = []
-        
+
         for signal in self.selfSignals:
             self.disconnect(signal)
         self.selfSignals = []
-        
+
         self.contactManager = ContactData.ContactList({})
         self.msnOIM.destroy()
         self.msnOIM = None
@@ -851,7 +844,7 @@ class Msnp(ProfileManager.ProfileManager):
             self.soapManager = None
         except:
             pass
-        
+
         # cleanup switchboards
         for sb in self.switchboards:
             try:
@@ -861,7 +854,7 @@ class Msnp(ProfileManager.ProfileManager):
                 pass
         self.switchboards = []
         self.switchboardsByTid = {}
-        
+
     def newSwitchboard(self):
         '''create a new Switchboard and return it'''
         tid = self.socket.tid
@@ -880,7 +873,7 @@ class Msnp(ProfileManager.ProfileManager):
         for sb in closed:
             self.switchboards.remove(sb)
         del closed
-        
+
     def on_display_picture_received(self, switchboard, msnobj, data, email):
         '''called when a display picture has been received'''
         contact = self.contactManager.getContact(email)
@@ -905,7 +898,7 @@ class Msnp(ProfileManager.ProfileManager):
             dir = os.path.join(self.cacheDir, 'wink_' + sha1d)
             if not os.path.exists(dir):
                 os.mkdir(dir)
-                
+
             path = os.path.join(dir, 'wink.cab')
             open(path, 'wb').write(data)
         except IOError:
@@ -918,7 +911,7 @@ class Msnp(ProfileManager.ProfileManager):
         from a signal'''
         self.switchboards.append(switchboard)
         self.emit('new-switchboard', switchboard)
-        
+
     def getSwitchboard(self, email):
         '''try to retrieve an existing switchboard that has email as the first
         user and its not a group chat. Clean up closed switchboards and create
@@ -939,12 +932,12 @@ class Msnp(ProfileManager.ProfileManager):
         '''return the groups in the userlist'''
 
         return self.contactManager.groups
-    
+
     def getGroupNames(self):
         '''Returns a list with the group names in the user list'''
         groups = self.contactManager.getGroupNames()
         groups.sort( key= lambda x: x.lower() )
-        
+
         return groups
 
     def checkPending(self):
@@ -988,23 +981,23 @@ class Msnp(ProfileManager.ProfileManager):
         else:
             self.msnobj = self.msnObjectsManager.create('', filename, \
                 type=Msnobj.Msnobj.DISPLAY_PICTURE)
-            
+
             myself = self.contactManager.getContact(self.user)
             if myself != None:
                 myself.displayPicturePath = filename
-            
+
         if self.status != 'FLN':
             self.changeStatus(self.status)
-            
+
     def createCustomEmoticon(self, shortcut, filename):
         self.msnObjectsManager.create(shortcut, filename, type=Msnobj.Msnobj.CUSTOM_EMOTICON)
-        
+
     def getMsnObjectsManager(self):
         return self.msnObjectsManager
-    
+
     def getUser(self):
         return self.user
-    
+
     def getNick(self):
         return self.nick
 
