@@ -478,6 +478,8 @@ class FTReceiver(Base):
         p2p.start_new_conv()
         p2p.emit('file-transfer-invite', int(self.session_id), \
             self.context, self.from_)
+        # ugly, but effective
+        p2p.manager.msn.emit('new-file-transfer',self.to_, self.context.filename)
         
     def on_file_transfer_accepted(self, p2p, session, context, sender):
         '''callback for P2PUser file-transfer-accepted, sends a 200ok
@@ -538,6 +540,8 @@ class FTReceiver(Base):
             self.debug('file-transfer-complete')
             p2p.emit('file-transfer-complete', int(self.session_id),
                 self.context, rc, self.from_)
+            # ugly, but effective
+            p2p.manager.msn.emit('finished-file-transfer',self.to_,self.context.filename)
             self.disconnect_handler(p2p)
 
 
