@@ -52,7 +52,9 @@ def _parse_css_color(color):
     if color.startswith("rgb(") and color.endswith(')'):
         r, g, b = [int(c)*257 for c in color[4:-1].split(',')]
         return gtk.gdk.Color(r, g, b)
-    else:
+    else: # there's some strange issue with colors starting with double #
+        if color.startswith('##'): 
+            color = '#0' + color.lstrip('#')
         return gtk.gdk.color_parse(color)
 
 
