@@ -19,6 +19,7 @@
 import Plugin
 import gtk
 import re
+import gobject
 from Parser import TAGS_NONE
 
 PLUGIN_NAME = 'CustomStatus'
@@ -58,11 +59,16 @@ class MainClass(Plugin.Plugin):
                         'filter', self.customStatus.customStatusParser)
         self.controller.emit('preferences-changed')  
         self.customStatus.unsetCustomStatus()
+        self.customStatus.register_slash_commands()
+        statusMenuItem = gtk.MenuItem (_('Custom status...'), False)
+        statusMenuItem.connect("activate", self.on_status_menu_activated)
+        self.controller.mainWindow.userPanel.statusMenu.add(statusMenuItem)
         self.enabled = True
 
     def stop(self):
         self.disconnect(self.onStatusChangeId)
         self.controller.unifiedParser.disconnect(self.customStatusParserId)
+        self.customStatus.unregister_slash_commands()
         self.enabled = False
 
     def check(self):
@@ -72,6 +78,8 @@ class MainClass(Plugin.Plugin):
         CustomStatusDialog(self.customStatus, DIALOG_TYPE_CONFIG).run()
         return True
 
+    def on_status_menu_activated(self, item):
+        self.customStatus.statusChanged(None, "AWY")
 
 class CustomStatus:
     '''
@@ -86,12 +94,13 @@ class CustomStatus:
         self.msn = msn
         self.config = config
         self.name = PLUGIN_NAME
+        self.slash = controller.Slash
 
         # We need a semaphore to block the status changing
         self.doChange = True
 
         # Status list permitted as custom status
-        self.permitted_status = ['AWY', 'BSY', 'BRB', 'PHN', 'LUN']
+        self.permitted_status = ['AWY', 'BSY']
 
     def customStatusParser(self, obj, parser, filterdata):
         '''This method (connected to unifiedParser) replaces ugly {..} tag
@@ -133,10 +142,10 @@ class CustomStatus:
             # We temporary block custom status changing to avoid double-dialog
             self.doChange = False
 
-            response = CustomStatusDialog(self, DIALOG_TYPE_SET, status).run()
+            response = CustomStatusDialog(self, DIALOG_TYPE_SET, status, "status_changed").run()
             if response != None:
                 status_type, status_name,\
-                    automessage, automessage_text = response
+                    automessage, automessage_text, slash_command = response
                 self.setCustomStatus(status_type, status_name,\
                                         automessage, automessage_text)
             # We enable again custom status changing
@@ -154,7 +163,6 @@ class CustomStatus:
        
         if automessage_enabled and autoreply_message != '':            
             self.controller.config.user['autoReply'] = True
-            self.controller.mainWindow.menu.activateAutoReply.set_active(True)
             self.controller.autoReplyMessage = autoreply_message
             self.controller.config.user['autoReplyMessage'] = autoreply_message
 
@@ -166,11 +174,10 @@ class CustomStatus:
         if self.msn.getNick() != newnick:
             self.msn.changeNick(statusTag.sub('', self.msn.getNick()))
         self.controller.config.user['autoReply'] = False
-        self.controller.mainWindow.menu.activateAutoReply.set_active(False)
 
     def loadSavedStatus(self):
         '''Method that loads saved custom statuses. It returns a list of lists 
-        [statustype, statusname, autoreplyenabled, autoreplymessage]'''
+        [statustype, statusname, autoreplyenabled, autoreplymessage, slashcommand]'''
 
         numStatus = self.config.getPluginValue(self.name,\
                                                 'custom_status_count', 0)
@@ -187,10 +194,12 @@ class CustomStatus:
                                                     'cAR'+str(i), None)
             cARMessage = self.config.getPluginValue(self.name,\
                                                     'cARMessage'+str(i), None)
-            
+            cCommand = self.config.getPluginValue(self.name, \
+                                                    'cCommand'+str(i), "")
+
             if not (cStatus == None or cName == None or \
                     cAR == None or cARMessage == None):
-                data.append([cStatus,cName,bool(int(cAR)),cARMessage])        
+                data.append([cStatus,cName,bool(int(cAR)),cARMessage, cCommand])        
 
         return data
 
@@ -204,10 +213,40 @@ class CustomStatus:
                                                         str(int(data[i][2])))
             self.config.setPluginValue(self.name, 'cARMessage'+str(i), \
                                                         data[i][3])
+            self.config.setPluginValue(self.name, 'cCommand'+str(i), \
+                                                        data[i][4])
 
         # We need to update custom statuses count
         self.config.setPluginValue(self.name, 'custom_status_count', len(data))
 
+    def register_slash_commands(self):
+        numStatus = self.config.getPluginValue(self.name,\
+                                                'custom_status_count', 0)
+        for i in range(int(numStatus)):
+            cCommand = self.config.getPluginValue(self.name, \
+                                                    'cCommand'+str(i), None)
+            if not ((cCommand == None) or (cCommand == "")):
+                self.slash.register(cCommand, self.on_slash_command, \
+                                          _("Applies a custom status"))
+
+    def unregister_slash_commands(self):
+        numStatus = self.config.getPluginValue(self.name,\
+                                                'custom_status_count', 0)
+        for i in range(int(numStatus)):
+            cCommand = self.config.getPluginValue(self.name, \
+                                                    'cCommand'+str(i), None)
+            if not ((cCommand == None) or (cCommand == "")):
+                self.slash.unregister(cCommand)
+
+    #search for al the custom statuses the one that matches the slash command
+    def on_slash_command(self, slash_action):
+        self.doChange = False
+        data = self.loadSavedStatus()
+        for i in data: #search every status
+            if i[4] == slash_action.name: #if slash_command = custom status command
+                self.setCustomStatus(i[0],i[1],i[2],i[3]) #change status
+        self.doChange = True
+
 
 class CustomStatusDialog(gtk.Dialog):
     '''
@@ -216,7 +255,7 @@ class CustomStatusDialog(gtk.Dialog):
     '''
 
     def __init__(self, customStatus, dialog_type=DIALOG_TYPE_SET, \
-                        current_status=None):
+                        current_status=None, source=""):
         '''Constructor'''
         
         gtk.Dialog.__init__(self , _('Custom status setting'), None, \
@@ -229,10 +268,22 @@ class CustomStatusDialog(gtk.Dialog):
         self.controller = self.customStatus.controller
 
         self.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
-        self.set_resizable(False)
-        self.set_border_width(12)
+        self.set_size_request(550,-1)
+        self.set_resizable(True)
+        self.set_border_width(10)
         self.set_has_separator(False)
-        self.vbox.set_spacing(20)
+        self.vbox.set_spacing(15)
+
+        #if the dialog appears changing status, the timer starts
+        #if the dialog is open with the Configure button in plugins manager, no timer 
+        if source == "status_changed":
+            self.timer_time = 10
+            self.title_text = _('Custom status setting - Closing in: %ds')
+            text = self.title_text % self.timer_time
+            self.set_property("title",text)
+            self.timer = gobject.timeout_add(1000,self.updateTimer)
+            self.set_focus_on_map(False) #dialog appears unfocused
+            self.connect('focus-in-event', self.disableTimer) #when focused, stop the timer
 
         # We load the saved custom statuses
         self.data = self.customStatus.loadSavedStatus()
@@ -251,9 +302,9 @@ class CustomStatusDialog(gtk.Dialog):
 
         # Listeners
         self.connect('delete-event', self.closeCancel)
-        self.create_panel.custom_status.connect('activate', self.closeOk)
+        self.create_panel.custom_status.connect('activate', self.closeAccept)
         self.create_panel.custom_autoreply_message.connect(\
-                                                'activate', self.closeOk)
+                                                'activate', self.closeAccept)
         self.select_panel.btn_add.connect('clicked', self.addStatus)
         self.select_panel.btn_remove.connect('clicked', self.delStatus)
         if dialog_type == DIALOG_TYPE_SET:
@@ -270,13 +321,13 @@ class CustomStatusDialog(gtk.Dialog):
         if status == None:
             return
 
-        status_type,status_name, automessage, automessage_text = status
+        status_type,status_name, automessage, automessage_text, command = status
         if automessage == False:
             automessage_text = ''
         self.select_panel.data.append([status_type, status_name, \
-                                        automessage, automessage_text])
+                                        automessage, automessage_text, command])
         self.select_panel.treeview.addStatusRow(status_type, status_name, \
-                                                automessage,automessage_text)
+                                                automessage,automessage_text,command)
         self.create_panel.clear()
 
     def delStatus(self, *args):
@@ -296,8 +347,8 @@ class CustomStatusDialog(gtk.Dialog):
         self.dataOK = self.data[view_column[0]]
         self.response(gtk.RESPONSE_OK)
 
-    def closeOk(self, *args):
-        '''Click on OK button'''
+    def closeAccept(self, *args):
+        '''Click on Accept button'''
         self.response(gtk.RESPONSE_ACCEPT)
 
     def closeCancel(self, *args):
@@ -307,22 +358,42 @@ class CustomStatusDialog(gtk.Dialog):
     def run(self):
         '''Method that manage the open and close of the dialog.'''
         response = gtk.Dialog.run(self)
-        self.destroy()   
+        self.destroy()
 
         # If we want to enable a custom status...
         if response == gtk.RESPONSE_ACCEPT or response == gtk.RESPONSE_OK:
+            self.customStatus.unregister_slash_commands()
+
             # We save the configuration
             self.customStatus.saveSavedStatus(self.select_panel.data)
 
+            self.customStatus.register_slash_commands()
+
             # We return the list containing choosed status settings.
             # If response is ACCEPT we use form data, else we use treeview data
             if response == gtk.RESPONSE_ACCEPT:
                 return (self.create_panel.getStatus())
-            return (self.dataOK)  
+            return (self.dataOK)
         # ... or if we click on Cancel button
         else:   
             return None
 
+    #this method updates the title of the dialog if the timer is running
+    def updateTimer(self):
+        self.timer_time = self.timer_time - 1
+        text = self.title_text % self.timer_time
+        self.set_property("title", text)
+        if self.timer_time == 0:
+            self.closeCancel()
+            return False
+        else:
+            return True
+
+    #disable the timer and change the title bar
+    def disableTimer(self, widget, event):
+        if self == widget:
+            gobject.source_remove(self.timer)
+            self.set_property("title", _('Custom status setting'))
 
 class CustomStatusTreeView(gtk.TreeView):
     '''
@@ -333,7 +404,7 @@ class CustomStatusTreeView(gtk.TreeView):
     def __init__(self, controller, data):
         '''Constructor'''
         
-        self.liststore = gtk.ListStore(str, str, bool, str)
+        self.liststore = gtk.ListStore(str, str, bool, str, str)
         self.controller = controller
         self.data = data
 
@@ -344,6 +415,7 @@ class CustomStatusTreeView(gtk.TreeView):
         cell1 = gtk.CellRendererText()
         cell2 = gtk.CellRendererToggle()
         cell3 = gtk.CellRendererText()
+        cell4 = gtk.CellRendererText()
 
         cell1.set_property('editable', True)
         cell1.connect('edited', self.onEdited, self.liststore, 1)
@@ -351,6 +423,8 @@ class CustomStatusTreeView(gtk.TreeView):
         cell2.connect('toggled', self.onToggled, self.liststore, 2)
         cell3.set_property('editable', True)
         cell3.connect('edited', self.onEdited, self.liststore, 3)
+        cell4.set_property('editable', True)
+        cell4.connect('edited', self.onEdited, self.liststore, 4)
 
         # Columns
         col0 = gtk.TreeViewColumn(_('Status'), cell0)
@@ -358,23 +432,26 @@ class CustomStatusTreeView(gtk.TreeView):
         col1 = gtk.TreeViewColumn(_('Status Name'), cell1, text=1)
         col2 = gtk.TreeViewColumn(_('A.R.'), cell2, active=2)
         col3 = gtk.TreeViewColumn(_('Autoreply message'), cell3, text=3)
+        col4 = gtk.TreeViewColumn(_('Command'), cell4, text=4)
         
         col1.set_resizable(True)
         col3.set_resizable(True)
+        col4.set_resizable(True)
         
         self.append_column(col0)
         self.append_column(col1)
         self.append_column(col2)
         self.append_column(col3)
+        self.append_column(col4)
 
         # We add the data to the table
         for item in self.data:
             self.liststore.append(item)
     
-    def addStatusRow(self, status, status_name, automessage, automessage_text):
+    def addStatusRow(self, status, status_name, automessage, automessage_text, command):
         '''Method that adds a row to the table using the liststore object'''
         self.liststore.append([status, status_name, \
-                                automessage, automessage_text])
+                                automessage, automessage_text, command])
 
     def getSelectedRow(self):
         '''Method that returns the currently selected row'''
@@ -579,7 +656,7 @@ class CustomStatusCreate(gtk.VBox):
                                     self.status_type.get_active_iter()])[0], \
                  self.custom_status.get_text().strip(), \
                  self.custom_autoreply_checkbox.get_active(), \
-                 self.custom_autoreply_message.get_text().strip())
+                 self.custom_autoreply_message.get_text().strip(),"")
 
     def enableAutoreply (self, *args):
         '''Method that enables autoreply text entry'''
