@@ -647,9 +647,9 @@ class MainClass(Plugin.Plugin):
         return self.logger.query(query % (account, num))
 
     def add_usermenu_item(self, controller, userMenu):
-        self.logMenuItem = userMenu.newImageMenuItem( _( "View conversation _log" ),
+        self.logMenuItem = userMenu.newImageMenuItem( _( "Conversation _log" ),
             gtk.STOCK_FILE )
-        userMenu.add( self.logMenuItem )
+        userMenu.viewMenu.add( self.logMenuItem )
         self.logMenuItem.show()
         self.logMenuItem.connect( 'activate', self.on_menuitem_activate, userMenu.user.email )
 
