@@ -27,13 +27,12 @@ from emesenelib.common import unescape
 from Parser import PangoDataType
 
 ERROR = ''
-#this is old code that has been replaced by module_require one
-#try:
-#    import pynotify
-#    if not pynotify.init("emesene"):
-#        raise
-#except:
-#    ERROR = _('there was a problem initializing the pynotify module')
+try:
+    import pynotify
+    if not pynotify.init("emesene"):
+        raise
+except:
+    ERROR = _('there was a problem initializing the pynotify module, install python-notify')
 
 class MainClass(Plugin.Plugin):
     '''Main plugin class'''
@@ -67,6 +66,8 @@ class MainClass(Plugin.Plugin):
         self.notifyOffline = int(self.config.getPluginValue(self.name, 'notifyOffline', '1'))
         self.notifyNewMail = int(self.config.getPluginValue(self.name, 'notifyMail', '1'))
         self.notifyTyping = int(self.config.getPluginValue(self.name, 'typing', '0'))
+        self.notifyFTInvite = int(self.config.getPluginValue(self.name, 'notifyFTInvite', '0'))
+        self.notifyFTFinished = int(self.config.getPluginValue(self.name, 'notifyFTFinished', '0'))
         self.notifyNewMsg = int(self.config.getPluginValue(self.name, 'notifyMessage', '1'))
         #self.notifyStarted = int(self.config.getPluginValue(self.name, 'notifyStarted', '0'))
         self.notifyBusy = int(self.config.getPluginValue(self.name, 'notifyBusy', '0'))
@@ -92,6 +93,8 @@ class MainClass(Plugin.Plugin):
         self.newMsgId = None
         self.offMsgId = None
         self.typingId = None
+        self.fTInviteId = None
+        self.fTFinishedId = None
         self.newMailId = None
         self.initMailId = None
         if Plugin.module_require(self.require, globals()):
@@ -114,6 +117,8 @@ class MainClass(Plugin.Plugin):
         self.newMsgId = self.connect('switchboard::message', self.newMsg)
         self.offMsgId = self.connect('offline-message-received', self.offMsg)
         self.typingId = self.connect('switchboard::typing', self.receiveTyping)
+        self.fTInviteId = self.msn.connect('new-file-transfer', self.notifyFileTransferInvite)
+        self.fTFinishedId = self.msn.connect('finished-file-transfer', self.notifyFileTransferFinished)
         self.newMailId = self.connect('new-mail-notification', self.newMail)
         self.initMailId = self.connect('initial-mail-notification', \
                 self.initMail)
@@ -135,6 +140,8 @@ class MainClass(Plugin.Plugin):
         self.disconnect(self.newMsgId)
         self.disconnect(self.offMsgId)
         self.disconnect(self.typingId)
+        self.disconnect(self.fTInviteId)
+        self.disconnect(self.fTFinishedId)
         self.disconnect(self.newMailId)
         self.disconnect(self.initMailId)
         self.enabled = False
@@ -178,6 +185,12 @@ class MainClass(Plugin.Plugin):
         l.append(Plugin.Option('typing', bool, \
                 _('Notify when someone starts typing'), '', self.config.\
                 getPluginValue(self.name, 'typing', '1') == '1'))
+        l.append(Plugin.Option('notifyFTInvite', bool, \
+                _('Notify when someone starts a file transfer'), '', self.config.\
+                getPluginValue(self.name, 'notifyFTInvite', '1') == '1'))
+        l.append(Plugin.Option('notifyFTFinished', bool, \
+                _('Notify when a file transfer finish'), '', self.config.\
+                getPluginValue(self.name, 'notifyFTFinished', '1') == '1'))
         l.append(Plugin.Option('notifyMessage', bool, \
                 _('Notify when receiving a message'), '', self.config.\
                 getPluginValue(self.name, 'notifyMessage', '1') == '1'))
@@ -206,6 +219,12 @@ class MainClass(Plugin.Plugin):
             if response.has_key('typing'):
                 self.config.setPluginValue(self.name, 'typing', \
                     str(int(response['typing'].value)))
+            if response.has_key('notifyFTInvite'):
+                self.config.setPluginValue(self.name, 'notifyFTInvite', \
+                    str(int(response['notifyFTInvite'].value)))
+            if response.has_key('notifyFTFinished'):
+                self.config.setPluginValue(self.name, 'notifyFTFinished', \
+                    str(int(response['notifyFTFinished'].value)))
             if response.has_key('notifyMessage'):
                 self.config.setPluginValue(self.name, 'notifyMessage', \
                     str(int(response['notifyMessage'].value)))
@@ -224,6 +243,10 @@ class MainClass(Plugin.Plugin):
                 (self.name, 'notifyMail', '1') == '1')
         self.notifyTyping = (self.config.getPluginValue \
                 (self.name, 'typing', '1') == '1')
+        self.notifyFTInvite = (self.config.getPluginValue \
+                (self.name, 'notifyFTInvite', '1') == '1')
+        self.notifyFTFinished = (self.config.getPluginValue \
+                (self.name, 'notifyFTFinished', '1') == '1')
         self.notifyNewMsg = (self.config.getPluginValue \
                 (self.name, 'notifyMessage', '1') == '1')
         #self.notifyStarted = (self.config.getPluginValue \
@@ -308,7 +331,7 @@ class MainClass(Plugin.Plugin):
             return
 
         contact, text = self.getNickPM(email)
-        status = "is online"
+        status = _("is online")
         self.notify(contact, text, status, 'conversation', (email, None))
 
     def offline(self, msnp, email):
@@ -318,7 +341,7 @@ class MainClass(Plugin.Plugin):
             return
 
         contact, text = self.getNickPM(email)
-        status = "is offline"
+        status = _("is offline")
         self.notify(contact, text, status)
 
     def newMsg(self, msn, switchboard, signal, args, stamp=None):
@@ -340,7 +363,7 @@ class MainClass(Plugin.Plugin):
                 return
 
             contact, title = self.getNickPM(email)
-            status = "has sent a message"
+            status = _("has sent a message")
             self.notify(contact, title, text, 'conversation', (email, None))
 
     def offMsg(self, msnp, oim):
@@ -359,7 +382,7 @@ class MainClass(Plugin.Plugin):
                 return
 
         contact, title = self.getNickPM(email)
-        status = "sent an offline message"
+        status = _("sent an offline message")
         self.notify(contact, title, status, 'conversation', (email, None))
 
     def receiveTyping(self, msn, switchboard, signal, args):
@@ -374,10 +397,30 @@ class MainClass(Plugin.Plugin):
             return
 
         contact, title = self.getNickPM(email)
-        status = "starts typing"
+        status = _('starts typing...')
         self.notify(contact, title, status, 'conversation', \
                 (email, switchboard))
 
+    def notifyFileTransferInvite(self, msnp,email,fileName):
+        '''called when someone starts a file transfer'''
+        if not (self.notifyFTInvite and self.notifyEnabled):
+            return
+
+        contact, text = self.getNickPM(email)
+        title = _('File transfer petition')
+        content = text + _(' wants to share ') + fileName
+        self.notify(contact, title, content, 'conversation', (email, None))
+
+    def notifyFileTransferFinished(self, msnp, email,fileName):
+        '''called when someone starts a file transfer'''
+        if not (self.notifyFTFinished and self.notifyEnabled):
+            return
+
+        contact, text = self.getNickPM(email)
+        title = _('File transfer complete')
+        content = fileName + _(' has been completly transfered')
+        self.notify(contact, title, content, 'conversation', (email, None))
+
     def newMail(self, msnp, From, FromAddr, Subject, MessageURL, PostURL, id):
         ''' called when receiving mail '''
 
@@ -409,6 +452,6 @@ class MainClass(Plugin.Plugin):
                         _('You have %(num)i unread message%(s)s') % \
                         {'num': unread, 's': s}, 'mail', (None, None, '2'))
 
-    def on_notify_close(self, n):
+    def on_notify_close(self, n, fedora_wtf=None):
         if n in self.notifications:
             self.notifications.remove(n)
