@@ -200,9 +200,11 @@ class MsnPlusMarkup:
 
     def codeToHex( self, data ):
         code=data.group()
-        if int(code) <= len(colorCodes):
+        if int(code) < len(colorCodes):
             hex = '#'+colorCodes[int(code)].lower()
             return hex
+        elif int(code) > 67 and int(code) < 100:
+            return '#000000'
         else:
             return code
 
