@@ -29,7 +29,9 @@ if name == 'posix':
     from Vagalume import Vagalume
     from Vlc import Vlc
     from Xfmedia import Xfmedia
+    from Spotify import Spotify
     from Xmms import Xmms
+    from Xmms2 import Xmms2
 else:
     from Winamp import Winamp
 
